@@ -66,6 +66,7 @@ Application::Application()
     , m_preventDisconnect(false)
     , m_callbacksInvoked(false)
     , m_requiresMainEventLoop(true)
+    , m_generalTimeout(10000)
     , m_idleDuration(0)
     , m_idleTimeout(0)
     , m_argsRead(false)
@@ -134,6 +135,7 @@ int Application::exec(int argc, const char *const *argv)
     }
 
     // finally do the request or establish connection
+    m_connection.setPollingFlags(SyncthingConnection::PollingFlags::MainEvents);
     if (m_args.status.isPresent() || m_args.rescan.isPresent() || m_args.rescanAll.isPresent() || m_args.pause.isPresent()
         || m_args.resume.isPresent() || m_args.waitForIdle.isPresent() || m_args.pwd.isPresent()) {
         // those arguments require establishing a connection first, the actual handler is called by handleStatusChanged() when
@@ -218,18 +220,19 @@ int Application::loadConfig()
         }
     }
 
-    // read idle duration and timeout
+    // read timeouts
     if (const int res = assignIntegerFromArg(m_args.atLeast, m_idleDuration)) {
         return res;
     }
     if (const int res = assignIntegerFromArg(m_args.timeout, m_idleTimeout)) {
         return res;
     }
-
-    // read request timeout
     if (const int res = assignIntegerFromArg(m_args.requestTimeout, m_settings.requestTimeout)) {
         return res;
     }
+    if (const int res = assignIntegerFromArg(m_args.requestTimeout, m_generalTimeout)) {
+        return res;
+    }
 
     // disable polling for information which is not used by any CLI operation so far
     m_settings.trafficPollInterval = 0;
@@ -239,31 +242,33 @@ int Application::loadConfig()
     return 0;
 }
 
-bool Application::waitForConnected(int timeout)
+bool Application::waitForConnected()
 {
     bool isConnected = m_connection.isConnected();
     const function<void(SyncthingStatus)> checkStatus([this, &isConnected](SyncthingStatus) { isConnected = m_connection.isConnected(); });
     return waitForSignalsOrFail(bind(static_cast<void (SyncthingConnection::*)(SyncthingConnectionSettings &)>(&SyncthingConnection::reconnect),
                                     ref(m_connection), ref(m_settings)),
-        timeout, signalInfo(&m_connection, &SyncthingConnection::error),
+        m_generalTimeout, signalInfo(&m_connection, &SyncthingConnection::error),
         signalInfo(&m_connection, &SyncthingConnection::statusChanged, checkStatus, &isConnected));
 }
 
-bool Application::waitForConfig(int timeout)
+bool Application::waitForConfig()
 {
     m_connection.applySettings(m_settings);
-    return waitForSignalsOrFail(bind(&SyncthingConnection::requestConfig, ref(m_connection)), timeout,
-        signalInfo(&m_connection, &SyncthingConnection::error), signalInfo(&m_connection, &SyncthingConnection::newConfig),
-        signalInfo(&m_connection, &SyncthingConnection::newDirs), signalInfo(&m_connection, &SyncthingConnection::newDevices));
+    return waitForSignalsOrFail(bind(&SyncthingConnection::requestConfig, ref(m_connection)), m_generalTimeout,
+        signalInfo(&m_connection, &SyncthingConnection::error), signalInfo(&m_connection, &SyncthingConnection::newConfig));
 }
 
-bool Application::waitForConfigAndStatus(int timeout)
+bool Application::waitForConfigAndStatus()
 {
     m_connection.applySettings(m_settings);
-    return waitForSignalsOrFail(bind(&SyncthingConnection::requestConfigAndStatus, ref(m_connection)), timeout,
-        signalInfo(&m_connection, &SyncthingConnection::error), signalInfo(&m_connection, &SyncthingConnection::newConfig),
-        signalInfo(&m_connection, &SyncthingConnection::newDirs), signalInfo(&m_connection, &SyncthingConnection::newDevices),
-        signalInfo(&m_connection, &SyncthingConnection::myIdChanged));
+    if (!waitForSignalsOrFail(bind(&SyncthingConnection::requestConfigAndStatus, ref(m_connection)), m_generalTimeout,
+            signalInfo(&m_connection, &SyncthingConnection::error), signalInfo(&m_connection, &SyncthingConnection::newConfig),
+            signalInfo(&m_connection, &SyncthingConnection::myIdChanged))) {
+        return false;
+    }
+    m_connection.applyRawConfig();
+    return true;
 }
 
 void Application::handleStatusChanged(SyncthingStatus newStatus)
@@ -532,7 +537,7 @@ void Application::printDir(const RelevantDir &relevantDir) const
     printProperty("Shared with", dir->deviceNames.isEmpty() ? dir->deviceIds : dir->deviceNames);
     printProperty("Download progress", dir->downloadLabel);
     if (!dir->completionByDevice.empty()) {
-        printProperty("Remote progress", dir->areRemotesUpToDate() ? "all up-to-date" : "some need bytes");
+        printProperty("Remote progress", dir->areRemotesUpToDate() ? "all up to date" : "some need bytes");
         for (const auto &completionForDev : dir->completionByDevice) {
             printProperty(m_connection.deviceNameOrId(completionForDev.first).toLocal8Bit().data(),
                 argsToString(dataSizeToString(completionForDev.second.globalBytes - completionForDev.second.needed.bytes), ' ', '/', ' ',
@@ -590,23 +595,23 @@ void Application::printStatus(const ArgumentOccurrence &)
     if (m_args.stats.isPresent() || (!m_args.dir.isPresent() && !m_args.dev.isPresent())) {
         cout << TextAttribute::Bold << "Overall statistics\n" << TextAttribute::Reset;
         const auto &overallStats(m_connection.computeOverallDirStatistics());
-        const auto *statusString = "idle";
+        const auto *statusString = "Up to Date";
         const auto *statusColor = "32";
         if (m_connection.hasOutOfSyncDirs()) {
-            statusString = "out-of-sync";
+            statusString = "Out of Sync";
             statusColor = "31";
         } else {
             switch (m_connection.status()) {
             case SyncthingStatus::Synchronizing:
-                statusString = "synchronizing";
+                statusString = "Syncing";
                 statusColor = "34";
                 break;
             case SyncthingStatus::RemoteNotInSync:
-                statusString = "remote synchronizing";
+                statusString = "Remote Syncing";
                 statusColor = "34";
                 break;
             case SyncthingStatus::Scanning:
-                statusString = "scanning";
+                statusString = "Scanning";
                 statusColor = "34";
                 break;
             default:;
@@ -1093,7 +1098,7 @@ void Application::initDirCompletion(Argument &arg, const ArgumentOccurrence &)
         return;
     }
     m_settings.requestTimeout = 5000; // avoid blocking shell for too long
-    waitForConfig();
+    waitForConfigAndStatus();
     // set directory IDs as completion values
     m_dirCompletion = m_connection.directoryIds().join(QChar(' ')).toUtf8();
     arg.setPreDefinedCompletionValues(m_dirCompletion.data());
@@ -1110,7 +1115,7 @@ void Application::initDevCompletion(Argument &arg, const ArgumentOccurrence &)
         return;
     }
     m_settings.requestTimeout = 5000; // avoid blocking shell for too long
-    waitForConfig();
+    waitForConfigAndStatus();
     // set device IDs and names as completion values
     QStringList completionValues;
     const size_t valueCount = m_connection.devInfo().size() << 2;
