@@ -10,6 +10,7 @@
 #include <syncthingwidgets/misc/internalerrorsdialog.h>
 #include <syncthingwidgets/misc/otherdialogs.h>
 #include <syncthingwidgets/misc/textviewdialog.h>
+#include <syncthingwidgets/misc/utils.h>
 #include <syncthingwidgets/settings/settings.h>
 #include <syncthingwidgets/settings/settingsdialog.h>
 #include <syncthingwidgets/settings/wizard.h>
@@ -90,15 +91,23 @@ SyncthingApplet::SyncthingApplet(QObject *parent, const QVariantList &data)
     , m_wizard(nullptr)
     , m_imageProvider(nullptr)
     , m_webViewDlg(nullptr)
+    , m_notificationsDlg(nullptr)
     , m_currentConnectionConfig(-1)
     , m_hasInternalErrors(false)
     , m_initialized(false)
     , m_showTabTexts(false)
     , m_applyingSettingsForWizard(false)
 {
+    // configure connection
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    m_connection.setPollingFlags(SyncthingConnection::PollingFlags::MainEvents | SyncthingConnection::PollingFlags::Errors);
+#endif
+    m_connection.setInsecure(Settings::values().connection.insecure);
+
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
     m_notifier.setService(&m_service);
 #endif
+
     m_sortFilterDirModel.sort(0, Qt::AscendingOrder);
     m_sortFilterDevModel.sort(0, Qt::AscendingOrder);
     qmlRegisterUncreatableMetaObject(Data::staticMetaObject, "martchus.syncthingplasmoid", 0, 6, "Data", QStringLiteral("only enums"));
@@ -139,17 +148,20 @@ void SyncthingApplet::init()
     connect(&m_notifier, &SyncthingNotifier::statusChanged, this, &SyncthingApplet::handleConnectionStatusChanged);
     connect(&m_notifier, &SyncthingNotifier::syncComplete, &m_dbusNotifier, &DBusStatusNotifier::showSyncComplete);
     connect(&m_notifier, &SyncthingNotifier::disconnected, &m_dbusNotifier, &DBusStatusNotifier::showDisconnect);
+    connect(&m_connection, &SyncthingConnection::autoReconnectIntervalChanged, this, &SyncthingApplet::updateStatusIconAndTooltip);
+    connect(&m_connection, &SyncthingConnection::hasOutOfSyncDirsChanged, this, &SyncthingApplet::updateStatusIconAndTooltip);
     connect(&m_connection, &SyncthingConnection::newDevices, this, &SyncthingApplet::handleDevicesChanged);
     connect(&m_connection, &SyncthingConnection::devStatusChanged, this, &SyncthingApplet::handleDevicesChanged);
     connect(&m_connection, &SyncthingConnection::error, this, &SyncthingApplet::handleInternalError);
     connect(&m_connection, &SyncthingConnection::trafficChanged, this, &SyncthingApplet::trafficChanged);
     connect(&m_connection, &SyncthingConnection::dirStatisticsChanged, this, &SyncthingApplet::handleDirStatisticsChanged);
     connect(&m_connection, &SyncthingConnection::newNotification, this, &SyncthingApplet::handleNewNotification);
+    connect(&m_connection, &SyncthingConnection::newErrors, this, &SyncthingApplet::updateStatusIconAndTooltip);
     connect(&m_notifier, &SyncthingNotifier::newDevice, &m_dbusNotifier, &DBusStatusNotifier::showNewDev);
     connect(&m_notifier, &SyncthingNotifier::newDir, &m_dbusNotifier, &DBusStatusNotifier::showNewDir);
     connect(&m_dbusNotifier, &DBusStatusNotifier::connectRequested, &m_connection,
         static_cast<void (SyncthingConnection::*)(void)>(&SyncthingConnection::connect));
-    connect(&m_dbusNotifier, &DBusStatusNotifier::dismissNotificationsRequested, this, &SyncthingApplet::dismissNotifications);
+    connect(&m_dbusNotifier, &DBusStatusNotifier::dismissNotificationsRequested, &m_connection, &SyncthingConnection::requestClearingErrors);
     connect(&m_dbusNotifier, &DBusStatusNotifier::showNotificationsRequested, this, &SyncthingApplet::showNotificationsDialog);
     connect(&m_dbusNotifier, &DBusStatusNotifier::errorDetailsRequested, this, &SyncthingApplet::showInternalErrorsDialog);
     connect(&m_dbusNotifier, &DBusStatusNotifier::webUiRequested, this, &SyncthingApplet::showWebUI);
@@ -320,11 +332,6 @@ bool SyncthingApplet::hasInternalErrors() const
     return m_hasInternalErrors;
 }
 
-bool SyncthingApplet::areNotificationsAvailable() const
-{
-    return !m_notifications.empty();
-}
-
 void SyncthingApplet::setPassiveStates(const QList<QtUtilities::ChecklistItem> &passiveStates)
 {
     m_passiveSelectionModel.setItems(passiveStates);
@@ -339,6 +346,13 @@ void SyncthingApplet::updateStatusIconAndTooltip()
     emit connectionStatusChanged();
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+void SyncthingApplet::handleRelevantControlsChanged(bool visible, int tabIndex)
+{
+    QtGui::handleRelevantControlsChanged(visible, tabIndex, m_connection);
+}
+#endif
+
 void SyncthingApplet::saveSettings()
 {
     Settings::save();
@@ -480,24 +494,13 @@ void SyncthingApplet::showAboutDialog()
 
 void SyncthingApplet::showNotificationsDialog()
 {
-    auto *const dlg = TextViewDialog::forLogEntries(m_notifications, tr("New notifications"));
-    dlg->setAttribute(Qt::WA_DeleteOnClose, true);
-    centerWidget(dlg);
-    dlg->show();
-    dismissNotifications();
-}
-
-void SyncthingApplet::dismissNotifications()
-{
-    m_connection.considerAllNotificationsRead();
-    if (m_notifications.empty()) {
-        return;
+    if (!m_notificationsDlg) {
+        m_notificationsDlg = errorNotificationsDialog(m_connection);
+        m_notificationsDlg->setAttribute(Qt::WA_DeleteOnClose, true);
+        connect(m_notificationsDlg, &QDialog::destroyed, this, &SyncthingApplet::handleNotificationsDialogDeleted);
     }
-    m_notifications.clear();
-    emit notificationsAvailableChanged(false);
-
-    // update status as well because having or not having notifications is relevant for status text/icon
-    updateStatusIconAndTooltip();
+    m_notificationsDlg->show();
+    m_notificationsDlg->activateWindow();
 }
 
 void SyncthingApplet::showInternalErrorsDialog()
@@ -548,6 +551,15 @@ void SyncthingApplet::copyToClipboard(const QString &text)
     QGuiApplication::clipboard()->setText(text);
 }
 
+void SyncthingApplet::openLocalFileOrDir(const QString &dirId, const QString &relativePath)
+{
+    if (auto dirIndex = 0; const auto *const dir = m_connection.findDirInfo(dirId, dirIndex)) {
+        QtUtilities::openLocalFileOrDir(QString(dir->path % QChar('/') % relativePath));
+    } else {
+        QMessageBox::warning(nullptr, QStringLiteral(APP_NAME), tr("Associated directory does not exist."));
+    }
+}
+
 /*!
  * \brief Ensures settings take effect when applied via the settings dialog.
  * \remarks Does not save the settings to disk. This is done in Settings::save() and Applet::configChanged().
@@ -623,17 +635,16 @@ void SyncthingApplet::handleWebViewDeleted()
     m_webViewDlg = nullptr;
 }
 
+void SyncthingApplet::handleNotificationsDialogDeleted()
+{
+    m_notificationsDlg = nullptr;
+}
+
 void SyncthingApplet::handleNewNotification(DateTime when, const QString &msg)
 {
-    m_notifications.emplace_back(QString::fromLocal8Bit(when.toString(DateTimeOutputFormat::DateAndTime, true).data()), msg);
     if (Settings::values().notifyOn.syncthingErrors) {
         m_dbusNotifier.showSyncthingNotification(when, msg);
     }
-    if (m_notifications.size() == 1) {
-        emit notificationsAvailableChanged(true);
-        // update status as well because having or not having notifications is relevant for status text/icon
-        updateStatusIconAndTooltip();
-    }
 }
 
 void SyncthingApplet::handleSystemdServiceError(const QString &context, const QString &name, const QString &message)
@@ -683,7 +694,7 @@ void SyncthingApplet::applySettings(int changeConnectionIndex)
     // apply appearance settings
     setSize(config.readEntry<QSize>("size", QSize(25, 25)));
     setShowingTabTexts(config.readEntry<bool>("showTabTexts", false));
-    IconManager::instance().applySettings(&settings.icons.status);
+    IconManager::instance().applySettings(&settings.icons.status, nullptr, settings.icons.usePaletteForStatus, false);
 
     // restore selected states
     // note: The settings dialog writes this to the Plasmoid's config like the other settings. However, it
