@@ -53,16 +53,16 @@ class SettingsDialog;
 
 class SyncthingApplet : public Plasma::Applet {
     Q_OBJECT
-    Q_PROPERTY(Data::SyncthingConnection *connection READ connection NOTIFY connectionChanged)
-    Q_PROPERTY(Data::SyncthingDirectoryModel *dirModel READ dirModel NOTIFY dirModelChanged)
-    Q_PROPERTY(Data::SyncthingSortFilterModel *sortFilterDirModel READ sortFilterDirModel NOTIFY dirModelChanged)
-    Q_PROPERTY(Data::SyncthingDeviceModel *devModel READ devModel NOTIFY devModelChanged)
-    Q_PROPERTY(Data::SyncthingSortFilterModel *sortFilterDevModel READ sortFilterDevModel NOTIFY devModelChanged)
-    Q_PROPERTY(Data::SyncthingDownloadModel *downloadModel READ downloadModel NOTIFY downloadModelChanged)
-    Q_PROPERTY(Data::SyncthingRecentChangesModel *recentChangesModel READ recentChangesModel NOTIFY recentChangesModelChanged)
-    Q_PROPERTY(Data::SyncthingStatusSelectionModel *passiveSelectionModel READ passiveSelectionModel NOTIFY passiveSelectionModelChanged)
+    Q_PROPERTY(Data::SyncthingConnection *connection READ connection CONSTANT)
+    Q_PROPERTY(Data::SyncthingDirectoryModel *dirModel READ dirModel CONSTANT)
+    Q_PROPERTY(Data::SyncthingSortFilterModel *sortFilterDirModel READ sortFilterDirModel CONSTANT)
+    Q_PROPERTY(Data::SyncthingDeviceModel *devModel READ devModel CONSTANT)
+    Q_PROPERTY(Data::SyncthingSortFilterModel *sortFilterDevModel READ sortFilterDevModel CONSTANT)
+    Q_PROPERTY(Data::SyncthingDownloadModel *downloadModel READ downloadModel CONSTANT)
+    Q_PROPERTY(Data::SyncthingRecentChangesModel *recentChangesModel READ recentChangesModel CONSTANT)
+    Q_PROPERTY(Data::SyncthingStatusSelectionModel *passiveSelectionModel READ passiveSelectionModel CONSTANT)
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
-    Q_PROPERTY(Data::SyncthingService *service READ service NOTIFY serviceChanged)
+    Q_PROPERTY(Data::SyncthingService *service READ service CONSTANT)
 #endif
     Q_PROPERTY(bool local READ isLocal NOTIFY localChanged)
     Q_PROPERTY(QString statusText READ statusText NOTIFY connectionStatusChanged)
@@ -82,11 +82,10 @@ class SyncthingApplet : public Plasma::Applet {
     Q_PROPERTY(bool hasInternalErrors READ hasInternalErrors NOTIFY hasInternalErrorsChanged)
     Q_PROPERTY(QSize size READ size WRITE setSize NOTIFY sizeChanged)
     Q_PROPERTY(bool showTabTexts READ isShowingTabTexts WRITE setShowingTabTexts NOTIFY showTabTextsChanged)
-    Q_PROPERTY(bool notificationsAvailable READ areNotificationsAvailable NOTIFY notificationsAvailableChanged)
     Q_PROPERTY(bool passive READ isPassive NOTIFY passiveChanged)
     Q_PROPERTY(QList<QtUtilities::ChecklistItem> passiveStates READ passiveStates WRITE setPassiveStates)
     Q_PROPERTY(QString faUrl READ faUrl NOTIFY faUrlChanged)
-    Q_PROPERTY(bool wipFeaturesEnabled READ areWipFeaturesEnabled NOTIFY wipFeaturesEnabledChanged)
+    Q_PROPERTY(bool wipFeaturesEnabled READ areWipFeaturesEnabled CONSTANT)
 
 public:
     SyncthingApplet(QObject *parent, const QVariantList &data);
@@ -125,7 +124,6 @@ public:
     void setSize(const QSize &size);
     bool isShowingTabTexts() const;
     void setShowingTabTexts(bool showTabTexts);
-    bool areNotificationsAvailable() const;
     bool isPassive() const;
     const QList<QtUtilities::ChecklistItem> &passiveStates() const;
     void setPassiveStates(const QList<QtUtilities::ChecklistItem> &passiveStates);
@@ -145,30 +143,19 @@ public Q_SLOTS:
     void showOwnDeviceId();
     void showAboutDialog();
     void showNotificationsDialog();
-    void dismissNotifications();
     void showInternalErrorsDialog();
     void showDirectoryErrors(const QString &dirId);
     void browseRemoteFiles(const QString &dirId);
     void showIgnorePatterns(const QString &dirId);
     void copyToClipboard(const QString &text);
+    void openLocalFileOrDir(const QString &dirId, const QString &relativePath);
     void updateStatusIconAndTooltip();
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    void handleRelevantControlsChanged(bool visible, int index);
+#endif
     void saveSettings();
 
 Q_SIGNALS:
-    /// \remarks Never emitted, just to silence "... depends on non-NOTIFYable ..."
-    void connectionChanged();
-    /// \remarks Never emitted, just to silence "... depends on non-NOTIFYable ..."
-    void dirModelChanged();
-    /// \remarks Never emitted, just to silence "... depends on non-NOTIFYable ..."
-    void devModelChanged();
-    /// \remarks Never emitted, just to silence "... depends on non-NOTIFYable ..."
-    void downloadModelChanged();
-    /// \remarks Never emitted, just to silence "... depends on non-NOTIFYable ..."
-    void recentChangesModelChanged();
-    /// \remarks Never emitted, just to silence "... depends on non-NOTIFYable ..."
-    void passiveSelectionModelChanged();
-    /// \remarks Never emitted, just to silence "... depends on non-NOTIFYable ..."
-    void serviceChanged();
     void localChanged();
     void connectionStatusChanged();
     void trafficChanged();
@@ -178,11 +165,8 @@ Q_SIGNALS:
     void hasInternalErrorsChanged(bool hasInternalErrors);
     void sizeChanged(const QSize &size);
     void showTabTextsChanged(bool isShowingTabTexts);
-    void notificationsAvailableChanged(bool notificationsAvailable);
     void passiveChanged(bool passive);
     void faUrlChanged(const QString &faUrl);
-    /// \remarks Never emitted, just to silence "... depends on non-NOTIFYable ..."
-    void wipFeaturesEnabledChanged();
 
 private Q_SLOTS:
     void handleSettingsChanged();
@@ -194,6 +178,7 @@ private Q_SLOTS:
     void handleErrorsCleared();
     void handleAboutDialogDeleted();
     void handleWebViewDeleted();
+    void handleNotificationsDialogDeleted();
     void handleNewNotification(CppUtilities::DateTime when, const QString &msg);
     void handleSystemdServiceError(const QString &context, const QString &name, const QString &message);
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
@@ -232,9 +217,9 @@ private:
     SettingsDialog *m_settingsDlg;
     QtGui::Wizard *m_wizard;
     QtGui::DBusStatusNotifier m_dbusNotifier;
-    std::vector<Data::SyncthingLogEntry> m_notifications;
     QtForkAwesome::QuickImageProvider *m_imageProvider;
     QtGui::WebViewDialog *m_webViewDlg;
+    QDialog *m_notificationsDlg;
     int m_currentConnectionConfig;
     bool m_hasInternalErrors;
     bool m_initialized;
