@@ -85,13 +85,17 @@ SyncthingConnection::SyncthingConnection(
     , m_keepPolling(false)
     , m_abortingAllRequests(false)
     , m_connectionAborted(false)
+    , m_abortingToConnect(false)
     , m_abortingToReconnect(false)
     , m_requestCompletion(true)
+    , m_pollingFlags(PollingFlags::All)
+    , m_statusRecomputationFlags(StatusRecomputation::None)
     , m_lastEventId(0)
     , m_lastDiskEventId(0)
     , m_autoReconnectTries(0)
     , m_requestTimeout(SyncthingConnectionSettings::defaultRequestTimeout)
     , m_longPollingTimeout(SyncthingConnectionSettings::defaultLongPollingTimeout)
+    , m_diskEventLimit(SyncthingConnectionSettings::defaultDiskEventLimit)
     , m_totalIncomingTraffic(unknownTraffic)
     , m_totalOutgoingTraffic(unknownTraffic)
     , m_totalIncomingRate(0.0)
@@ -106,33 +110,32 @@ SyncthingConnection::SyncthingConnection(
     , m_versionReply(nullptr)
     , m_diskEventsReply(nullptr)
     , m_logReply(nullptr)
-    , m_unreadNotifications(false)
     , m_hasConfig(false)
     , m_hasStatus(false)
     , m_hasEvents(false)
     , m_hasDiskEvents(false)
     , m_lastFileDeleted(false)
-    , m_dirStatsAltered(false)
     , m_recordFileChanges(false)
     , m_useDeprecatedRoutes(true)
     , m_pausingOnMeteredConnection(false)
 #ifdef SYNCTHINGCONNECTION_SUPPORT_METERED
     , m_handlingMeteredConnectionInitialized(false)
 #endif
+    , m_insecure(false)
 {
     m_trafficPollTimer.setInterval(SyncthingConnectionSettings::defaultTrafficPollInterval);
-    m_trafficPollTimer.setTimerType(Qt::VeryCoarseTimer);
+    m_trafficPollTimer.setTimerType(Qt::CoarseTimer);
     m_trafficPollTimer.setSingleShot(true);
     QObject::connect(&m_trafficPollTimer, &QTimer::timeout, this, &SyncthingConnection::requestConnections);
     m_devStatsPollTimer.setInterval(SyncthingConnectionSettings::defaultDevStatusPollInterval);
-    m_devStatsPollTimer.setTimerType(Qt::VeryCoarseTimer);
+    m_devStatsPollTimer.setTimerType(Qt::CoarseTimer);
     m_devStatsPollTimer.setSingleShot(true);
     QObject::connect(&m_devStatsPollTimer, &QTimer::timeout, this, &SyncthingConnection::requestDeviceStatistics);
     m_errorsPollTimer.setInterval(SyncthingConnectionSettings::defaultErrorsPollInterval);
-    m_errorsPollTimer.setTimerType(Qt::VeryCoarseTimer);
+    m_errorsPollTimer.setTimerType(Qt::CoarseTimer);
     m_errorsPollTimer.setSingleShot(true);
     QObject::connect(&m_errorsPollTimer, &QTimer::timeout, this, &SyncthingConnection::requestErrors);
-    m_autoReconnectTimer.setTimerType(Qt::VeryCoarseTimer);
+    m_autoReconnectTimer.setTimerType(Qt::CoarseTimer);
     m_autoReconnectTimer.setInterval(SyncthingConnectionSettings::defaultReconnectInterval);
     QObject::connect(&m_autoReconnectTimer, &QTimer::timeout, this, &SyncthingConnection::autoReconnect);
 
@@ -235,17 +238,109 @@ void SyncthingConnection::setLoggingFlags(SyncthingConnectionLoggingFlags flags)
     }
 }
 
+/*!
+ * \brief Cancels \a reply without considering the connection aborted.
+ * \remarks Setting \a reply back to nullptr before aborting it avoids the usual cancellation handler to be invoked.
+ */
+static inline void cancelReplyWithoutAbortingConnection(QNetworkReply *&reply)
+{
+    if (reply) {
+        std::exchange(reply, nullptr)->abort();
+    }
+}
+
+/*!
+ * \brief Ensure the request with the specified \a timer, \a pendingReply and \a requestFunction is enabled or disabled depending on \a enable.
+ * \remarks This function is only supposed to be called if \a enabled has actually changed.
+ */
+static inline void manageTimerBasedRequest(
+    QTimer &timer, QNetworkReply *pendingReply, SyncthingConnection &connection, void (SyncthingConnection::*requestFunction)(void), bool enable)
+{
+    // stop any possibly active timer if the polling-flag has been disabled (stopping a pending request would be possible but not gain us anything)
+    if (!enable) {
+        timer.stop();
+        return;
+    }
+
+    // make a request immediately (unless there's already a pending reply) if the polling-flag has been enabled and a non-zero polling interval is configured
+    if (timer.interval() && !pendingReply) {
+        timer.stop();
+        std::invoke(requestFunction, connection);
+    }
+}
+
+/*!
+ * \brief Returns whether flags matching the specified \a mask have been changed between \a flags1 and \a flags2.
+ */
+static inline bool haveFlagsChanged(
+    SyncthingConnection::PollingFlags flags1, SyncthingConnection::PollingFlags flags2, SyncthingConnection::PollingFlags mask)
+{
+    return (flags1 & mask) != (flags2 & mask);
+}
+
+/*!
+ * \brief Sets what kind of events are polled for.
+ * \remarks
+ * - Call this function to reduce CPU usage in case not all events are needed right now, e.g. remove PollingFlags::DiskEvents
+ *   if the fileChanged() signal is not used anyway.
+ * - Restarts pending requests as necessary.
+ */
+void SyncthingConnection::setPollingFlags(PollingFlags flags)
+{
+    if (flags == m_pollingFlags) {
+        return;
+    }
+
+    // track what flags have changed and set new flags
+    const auto normalEventsChanged = haveFlagsChanged(flags, m_pollingFlags, PollingFlags::NormalEvents);
+    const auto diskEventsChanged = haveFlagsChanged(flags, m_pollingFlags, PollingFlags::DiskEvents);
+    const auto trafficStatsChanged = haveFlagsChanged(flags, m_pollingFlags, PollingFlags::TrafficStatistics);
+    const auto devStatsChanged = haveFlagsChanged(flags, m_pollingFlags, PollingFlags::DeviceStatistics);
+    const auto errorsChanged = haveFlagsChanged(flags, m_pollingFlags, PollingFlags::Errors);
+    m_pollingFlags = flags;
+
+    // restart events/disk-events request as necessary
+    if (normalEventsChanged) {
+        m_eventMask.clear();
+        cancelReplyWithoutAbortingConnection(m_eventsReply);
+    }
+    if (diskEventsChanged) {
+        cancelReplyWithoutAbortingConnection(m_diskEventsReply);
+    }
+    if (m_keepPolling) {
+        requestEvents();
+        requestDiskEvents(m_diskEventLimit);
+    }
+
+    // manage timers/requests for timer-based requests
+    if (trafficStatsChanged) {
+        manageTimerBasedRequest(m_trafficPollTimer, m_connectionsReply, *this, &SyncthingConnection::requestConnections,
+            m_keepPolling && (m_pollingFlags & PollingFlags::TrafficStatistics));
+    }
+    if (devStatsChanged) {
+        manageTimerBasedRequest(m_devStatsPollTimer, m_devStatsReply, *this, &SyncthingConnection::requestDeviceStatistics,
+            m_keepPolling && (m_pollingFlags & PollingFlags::DeviceStatistics));
+    }
+    if (errorsChanged) {
+        manageTimerBasedRequest(
+            m_errorsPollTimer, m_errorsReply, *this, &SyncthingConnection::requestErrors, m_keepPolling && (m_pollingFlags & PollingFlags::Errors));
+    }
+}
+
 /*!
  * \brief Returns whether there is at least one directory out-of-sync.
  */
 bool SyncthingConnection::hasOutOfSyncDirs() const
 {
+    if (m_hasOutOfSyncDirs.has_value()) {
+        return m_hasOutOfSyncDirs.value();
+    }
     for (const SyncthingDir &dir : m_dirs) {
-        if (dir.status == SyncthingDirStatus::OutOfSync) {
-            return true;
+        if (!dir.paused && dir.status == SyncthingDirStatus::OutOfSync) {
+            return m_hasOutOfSyncDirs.emplace(true);
         }
     }
-    return false;
+    return m_hasOutOfSyncDirs.emplace(false);
 }
 
 /*!
@@ -281,6 +376,14 @@ void SyncthingConnection::setPausingOnMeteredConnection(bool pausingOnMeteredCon
     }
 }
 
+/*!
+ * \brief Substitutes the tilde as first element in \a path using current values of tilde() and pathSeparator().
+ */
+QString SyncthingConnection::substituteTilde(const QString &path) const
+{
+    return Data::substituteTilde(path, m_tilde, m_pathSeparator);
+}
+
 /*!
  * \brief Ensures that devices are paused/resumed depending on whether the network connection is metered.
  */
@@ -333,22 +436,37 @@ void SyncthingConnection::connect()
         return;
     }
 
-    // reset status
-    m_connectionAborted = m_abortingToReconnect = m_hasConfig = m_hasStatus = m_hasEvents = m_hasDiskEvents = false;
-
-    // check configuration
-    if (m_apiKey.isEmpty() || m_syncthingUrl.isEmpty()) {
-        emit error(tr("Connection configuration is insufficient."), SyncthingErrorCategory::OverallConnection, QNetworkReply::NoError);
-        setStatus(SyncthingStatus::Disconnected);
+    // abort pending requests before connecting
+    if (hasPendingRequests()) {
+        m_keepPolling = m_abortingToConnect = true;
+        abortAllRequests();
         return;
     }
 
-    // start by requesting config and status; if both are available request further info and events
+    // reset status
+    m_connectionAborted = m_abortingToConnect = m_abortingToReconnect = m_hasConfig = m_hasStatus = m_hasEvents = m_hasDiskEvents = false;
+
+    if (!checkConnectionConfiguration()) {
+        return;
+    }
     requestConfig();
     requestStatus();
     m_keepPolling = true;
 }
 
+/*!
+ * \brief Returns whether the connection configuration is sufficient and sets the connection into the disconnected state if not.
+ */
+bool SyncthingConnection::checkConnectionConfiguration()
+{
+    if (!m_apiKey.isEmpty() && !m_syncthingUrl.isEmpty()) {
+        return true;
+    }
+    emit error(tr("Connection configuration is insufficient."), SyncthingErrorCategory::OverallConnection, QNetworkReply::NoError);
+    setStatus(SyncthingStatus::Disconnected);
+    return false;
+}
+
 /*!
  * \brief Applies the specified configuration and tries to reconnect via reconnect() if properties requiring reconnect
  *        to take effect have changed.
@@ -363,11 +481,11 @@ void SyncthingConnection::connect(SyncthingConnectionSettings &connectionSetting
 
 /*!
  * \brief Connects in \a milliSeconds. Useful to "schedule" another attempt in case of a failure.
- * \remarks Does nothing if the connection attempt would happen anyways though auto-reconnect.
+ * \remarks Does nothing if the connection attempt would happen anyway though auto-reconnect.
  */
 void SyncthingConnection::connectLater(int milliSeconds)
 {
-    // skip if conneting via auto-reconnect anyways
+    // skip if connecting via auto-reconnect anyway
     if (m_autoReconnectTimer.isActive() && milliSeconds > m_autoReconnectTimer.interval()) {
         return;
     }
@@ -379,7 +497,8 @@ void SyncthingConnection::connectLater(int milliSeconds)
  */
 void SyncthingConnection::disconnect()
 {
-    m_abortingToReconnect = m_keepPolling = false;
+    m_abortingToConnect = m_abortingToReconnect = m_keepPolling = false;
+    m_statusRecomputationFlags = StatusRecomputation::None;
     m_trafficPollTimer.stop();
     m_devStatsPollTimer.stop();
     m_errorsPollTimer.stop();
@@ -481,7 +600,7 @@ void SyncthingConnection::reconnectLater(int milliSeconds)
  */
 void SyncthingConnection::continueReconnecting()
 {
-    // notify that we're about to invalidate the configuration if not already invalidated anyways
+    // notify that we're about to invalidate the configuration if not already invalidated anyway
     const auto isConfigInvalidated = m_rawConfig.isEmpty();
     if (!isConfigInvalidated) {
         emit newConfig(m_rawConfig = QJsonObject());
@@ -489,8 +608,9 @@ void SyncthingConnection::continueReconnecting()
 
     // cleanup information from previous connection
     m_keepPolling = true;
+    m_statusRecomputationFlags = StatusRecomputation::None;
     m_connectionAborted = false;
-    m_abortingToReconnect = false;
+    m_abortingToConnect = m_abortingToReconnect = false;
     m_lastEventId = 0;
     m_lastDiskEventId = 0;
     m_configDir.clear();
@@ -502,13 +622,14 @@ void SyncthingConnection::continueReconnecting()
     m_totalIncomingRate = 0.0;
     m_totalOutgoingRate = 0.0;
     emit trafficChanged(unknownTraffic, unknownTraffic);
-    m_unreadNotifications = false;
+    m_hasOutOfSyncDirs.reset();
     m_hasConfig = false;
     m_hasStatus = false;
     m_hasEvents = false;
     m_hasDiskEvents = false;
     m_dirs.clear();
     m_devs.clear();
+    m_errors.clear();
     m_devsPausedDueToMeteredConnection.clear();
     m_lastConnectionsUpdateEvent = 0;
     m_lastConnectionsUpdateTime = DateTime();
@@ -519,7 +640,6 @@ void SyncthingConnection::continueReconnecting()
     m_lastFileName.clear();
     m_lastFileDeleted = false;
     m_syncthingVersion.clear();
-    m_dirStatsAltered = false;
     emit dirStatisticsChanged();
 
     // notify that the configuration has been invalidated
@@ -527,18 +647,24 @@ void SyncthingConnection::continueReconnecting()
         emit newConfigApplied();
     }
 
-    if (m_apiKey.isEmpty() || m_syncthingUrl.isEmpty()) {
-        emit error(tr("Connection configuration is insufficient."), SyncthingErrorCategory::OverallConnection, QNetworkReply::NoError);
-        setStatus(SyncthingStatus::Disconnected);
+    if (!checkConnectionConfiguration()) {
         return;
     }
-
     requestConfig();
     requestStatus();
-
     setStatus(SyncthingStatus::Reconnecting);
 }
 
+/*!
+ * \brief Reads devs and dirs from the raw config.
+ */
+void SyncthingConnection::applyRawConfig()
+{
+    readDevs(m_rawConfig.value(QLatin1String("devices")).toArray());
+    readDirs(m_rawConfig.value(QLatin1String("folders")).toArray());
+    emit newConfigApplied();
+}
+
 /*!
  * \brief Reads results of requestConfig() and requestStatus().
  * \remarks Called in readConfig() or readStatus() to conclude reading parts requiring config *and* status
@@ -550,25 +676,38 @@ void SyncthingConnection::concludeReadingConfigAndStatus()
         return;
     }
 
-    readDevs(m_rawConfig.value(QLatin1String("devices")).toArray());
-    readDirs(m_rawConfig.value(QLatin1String("folders")).toArray());
-    emit newConfigApplied();
-
+    applyRawConfig();
     continueConnecting();
 }
 
 /*!
- * \brief Sets the state from (re)connecting to Syncthing's actual state if polling but there are no more pending requests.
- * \remarks Called by read...() handlers for requests started in continueConnecting().
+ * \brief Sets the status from (re)connecting to Syncthing's actual state if polling but there are no more pending requests.
+ * \remarks
+ * - Called by read...() handlers for requests started in continueConnecting().
+ * - The flags are used to decide whether the status should be recomputed (as not all read...() handlers require a recomputation).
  * \sa hasPendingRequests()
  */
-void SyncthingConnection::concludeConnection()
+void SyncthingConnection::concludeConnection(StatusRecomputation flags)
 {
-    if (!m_keepPolling || hasPendingRequests()) {
+    if (!m_keepPolling) {
         return;
     }
-    setStatus(SyncthingStatus::Idle);
-    emitDirStatisticsChanged();
+
+    // take always record of the specified flags but return early if there are still pending requests or the status does not need to be recomputed
+    m_statusRecomputationFlags += flags;
+    if (hasPendingRequests() || (m_statusRecomputationFlags == StatusRecomputation::None && isConnected())) {
+        return;
+    }
+
+    // recompute status and emit events according to flags
+    if (!setStatus(SyncthingStatus::Idle) && (m_statusRecomputationFlags & StatusRecomputation::OutOfSyncDirs) && !m_hasOutOfSyncDirs.has_value()) {
+        emit hasOutOfSyncDirsChanged();
+    }
+    if (m_statusRecomputationFlags & StatusRecomputation::DirStats) {
+        emit dirStatisticsChanged();
+    }
+
+    m_statusRecomputationFlags = StatusRecomputation::None;
 }
 
 /*!
@@ -675,7 +814,7 @@ SyncthingDir *SyncthingConnection::addDirInfo(std::vector<SyncthingDir> &dirs, c
     if (dirId.isEmpty()) {
         return nullptr;
     }
-    int row;
+    auto row = int();
     if (auto *const existingDirInfo = findDirInfo(dirId, row)) {
         return &dirs.emplace_back(std::move(*existingDirInfo));
     } else {
@@ -777,7 +916,7 @@ SyncthingDev *SyncthingConnection::addDevInfo(std::vector<SyncthingDev> &devs, c
     if (devId.isEmpty()) {
         return nullptr;
     }
-    int row;
+    auto row = int();
     if (SyncthingDev *const existingDevInfo = findDevInfo(devId, row)) {
         return &devs.emplace_back(std::move(*existingDevInfo));
     } else {
@@ -813,7 +952,6 @@ void SyncthingConnection::continueConnecting()
     }
 
     // read additional information (beside config and status)
-    // FIXME: make those requests configurable (eg. flag enum)
     requestConnections();
     requestDirStatistics();
     requestDeviceStatistics();
@@ -829,11 +967,12 @@ void SyncthingConnection::continueConnecting()
         }
     }
 
-    // poll for events
+    // poll for events according to polling flags
     requestEvents();
-    requestDiskEvents();
+    requestDiskEvents(m_diskEventLimit);
 }
 
+#ifndef QT_NO_SSL
 /*!
  * \brief Locates and loads the (self-signed) certificate used by the Syncthing GUI.
  * \remarks
@@ -898,6 +1037,7 @@ void SyncthingConnection::clearSelfSignedCertificate()
     m_dynamicallyDeterminedCertificatePath.clear();
     m_certificateLastModified = QDateTime();
 }
+#endif
 
 /*!
  * \brief Applies the specified configuration.
@@ -930,6 +1070,7 @@ bool SyncthingConnection::applySettings(SyncthingConnectionSettings &connectionS
         }
         reconnectRequired = true;
     }
+#ifndef QT_NO_SSL
     m_certificatePath = connectionSettings.httpsCertPath;
     m_certificateLastModified = connectionSettings.httpCertLastModified;
     if (connectionSettings.expectedSslErrors.isEmpty()) {
@@ -943,6 +1084,7 @@ bool SyncthingConnection::applySettings(SyncthingConnectionSettings &connectionS
         m_expectedSslErrors = connectionSettings.expectedSslErrors;
         reconnectRequired = true;
     }
+#endif
 
     setTrafficPollInterval(connectionSettings.trafficPollInterval);
     setDevStatsPollInterval(connectionSettings.devStatsPollInterval);
@@ -950,6 +1092,7 @@ bool SyncthingConnection::applySettings(SyncthingConnectionSettings &connectionS
     setAutoReconnectInterval(connectionSettings.reconnectInterval);
     setRequestTimeout(connectionSettings.requestTimeout);
     setLongPollingTimeout(connectionSettings.longPollingTimeout);
+    setDiskEventLimit(connectionSettings.diskEventLimit);
     setStatusComputionFlags(connectionSettings.statusComputionFlags);
     setPausingOnMeteredConnection(connectionSettings.pauseOnMeteredConnection);
 
@@ -974,11 +1117,13 @@ bool SyncthingConnection::applySettings(SyncthingConnectionSettings &connectionS
  *   the SyncthingConnection::hasOutOfSyncDirs() function.
  * - Whether notifications are available is *not* handled by this function. One needs to query this via
  *   SyncthingConnection::hasUnreadNotifications().
+ * \returns Returns whether the status has been changed; the the status remained the same as before false
+ *          is returned. Returns always true if the connection is being destroyed.
  */
-void SyncthingConnection::setStatus(SyncthingStatus status)
+bool SyncthingConnection::setStatus(SyncthingStatus status)
 {
     if (m_status == SyncthingStatus::BeingDestroyed) {
-        return;
+        return true;
     }
     switch (status) {
     case SyncthingStatus::Disconnected:
@@ -1021,7 +1166,7 @@ void SyncthingConnection::setStatus(SyncthingStatus status)
                 default:;
                 }
                 if (synchronizing) {
-                    break; // skip remaining dirs, "synchronizing" overrides "scanning" anyways
+                    break; // skip remaining dirs, "synchronizing" overrides "scanning" anyway
                 }
             }
         }
@@ -1052,10 +1197,12 @@ void SyncthingConnection::setStatus(SyncthingStatus status)
             }
         }
     }
-    if (m_status != status || status == SyncthingStatus::Disconnected) {
+    const auto hasStatusChanged = m_status != status || status == SyncthingStatus::Disconnected;
+    if (hasStatusChanged) {
         // emit event if status changed always for disconnects so isConnecting() is re-evaluated
         emit statusChanged(m_status = status);
     }
+    return hasStatusChanged;
 }
 
 /*!
@@ -1137,27 +1284,17 @@ void SyncthingConnection::emitTildeChanged(const QString &newTilde, const QStrin
     emit tildeChanged(m_tilde);
 }
 
-/*!
- * \brief Internally called to emit dirStatisticsChanged() event.
- */
-void SyncthingConnection::emitDirStatisticsChanged()
-{
-    if (m_dirStatsAltered) {
-        m_dirStatsAltered = false;
-        emit dirStatisticsChanged();
-    }
-}
-
 /*!
  * \brief Internally called to handle a fatal error when reading config (dirs/devs), status and events.
  */
 void SyncthingConnection::handleFatalConnectionError()
 {
-    setStatus(SyncthingStatus::Disconnected);
-    abortAllRequests();
-    if (m_autoReconnectTimer.interval()) {
+    // start the timer before emitting the event so its active state can be observed in event handler
+    if (m_autoReconnectTimer.interval() || !m_autoReconnectTimer.isActive()) {
         m_autoReconnectTimer.start();
     }
+    setStatus(SyncthingStatus::Disconnected);
+    abortAllRequests();
 }
 
 /*!
@@ -1170,8 +1307,11 @@ void SyncthingConnection::handleAdditionalRequestCanceled()
         return;
     }
     if (m_abortingToReconnect) {
-        // if reconnection flag is set, instantly etstablish a new connection ...
+        // if reconnect-flag is set, instantly etstablish a new connection via reconnect()
         continueReconnecting();
+    } else if (m_abortingToConnect) {
+        // if connect-flag is set, instantly establish a new connection via connect()
+        connect();
     } else {
         // ... otherwise declare we're disconnected if that was the last pending request
         setStatus(SyncthingStatus::Disconnected);
@@ -1193,6 +1333,29 @@ void SyncthingConnection::recalculateStatus()
     }
 }
 
+/*!
+ * \brief Invalidates whether there are currently out-of-sync dirs and provokes subscribers to the
+ *        hasOutOfSyncDirsChanged() event to re-evaluate it.
+ */
+void SyncthingConnection::invalidateHasOutOfSyncDirs()
+{
+    if (m_hasOutOfSyncDirs.has_value()) {
+        m_hasOutOfSyncDirs.reset();
+        emit hasOutOfSyncDirsChanged();
+    }
+}
+
+/*!
+ * \brief Returns syncthingUrl() with userName() and password().
+ */
+QUrl SyncthingConnection::makeUrlWithCredentials() const
+{
+    auto url = QUrl(m_syncthingUrl);
+    url.setUserName(m_user);
+    url.setPassword(m_password);
+    return url;
+}
+
 /*!
  * \fn SyncthingConnection::newConfig()
  * \brief Indicates new configuration (dirs, devs, ...) is available.
@@ -1221,13 +1384,13 @@ void SyncthingConnection::recalculateStatus()
  */
 
 /*!
- * \fn SyncthingConnection::allEventsProcesses()
+ * \fn SyncthingConnection::allEventsProcessed()
  * \brief Indicates all new events have been processed.
  * \remarks
- * This event is emitted after newEvents() and dirStatusChanged(), devStatusChanged() and other specific events.
- * If you would go through the list of all directories on every dirStatusChanged() event using instead might
- * be a more efficient alternative allEventsProcesses(). Just set a flag on dirStatusChanged() and go though the
- * list of directories only once on the allEventsProcesses() event when the flag has been set.
+ * This event is emitted after newEvents(), dirStatusChanged(), devStatusChanged() and other specific events.
+ * If you would go through the list of all directories on every dirStatusChanged() event then using allEventsProcessed()
+ * instead might be a more efficient alternative. Just set a flag on dirStatusChanged() and go though the list of
+ * directories only once on the allEventsProcessed() event when the flag has been set.
  */
 
 /*!
@@ -1319,4 +1482,16 @@ void SyncthingConnection::recalculateStatus()
  * \fn SyncthingConnection::restartTriggered()
  * \brief Indicates a restart has been successfully triggered via restart().
  */
+
+/*!
+ * \fn SyncthingConnection::hasOutOfSyncDirsChanged()
+ * \brief Indicates that hasOutOfSyncDirs() might has changed.
+ * \remarks
+ * - This signal is only emitted if hasOutOfSyncDirs() has been called at least once
+ *   since the connection has been established.
+ * - This signal is *not* emitted if the status has changed at the same time. Then only
+ *   statusChanged() is emitted. This is so that UI components subscribed to the event
+ *   are only updated once (as they will also be subscribed to statusChanged()).
+ */
+
 } // namespace Data
