@@ -21,6 +21,7 @@
 #include <cstdint>
 #include <functional>
 #include <limits>
+#include <optional>
 #include <vector>
 
 QT_FORWARD_DECLARE_CLASS(QNetworkAccessManager)
@@ -115,12 +116,18 @@ struct LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingIgnores {
     QStringList expanded;
 };
 
+struct LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingError {
+    CppUtilities::DateTime when;
+    QString message;
+};
+
 class LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConnection : public QObject {
     friend ConnectionTests;
     friend MiscTests;
 
     Q_OBJECT
-    Q_PROPERTY(QString syncthingUrl READ syncthingUrl WRITE setSyncthingUrl)
+    Q_PROPERTY(QString syncthingUrl READ syncthingUrl WRITE setSyncthingUrl NOTIFY syncthingUrlChanged)
+    Q_PROPERTY(QUrl syncthingUrlWithCredentials READ makeUrlWithCredentials NOTIFY syncthingUrlChanged)
     Q_PROPERTY(QByteArray apiKey READ apiKey WRITE setApiKey)
     Q_PROPERTY(bool isLocal READ isLocal)
     Q_PROPERTY(QString user READ user)
@@ -132,16 +139,17 @@ class LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConnection : public QObject {
     Q_PROPERTY(bool connected READ isConnected NOTIFY statusChanged)
     Q_PROPERTY(bool connecting READ isConnecting NOTIFY statusChanged)
     Q_PROPERTY(bool aborted READ isAborted NOTIFY statusChanged)
-    Q_PROPERTY(bool hasUnreadNotifications READ hasUnreadNotifications)
-    Q_PROPERTY(bool hasOutOfSyncDirs READ hasOutOfSyncDirs)
+    Q_PROPERTY(bool hasErrors READ hasErrors NOTIFY newErrors)
+    Q_PROPERTY(bool hasOutOfSyncDirs READ hasOutOfSyncDirs NOTIFY hasOutOfSyncDirsChanged)
     Q_PROPERTY(bool requestingCompletionEnabled READ isRequestingCompletionEnabled WRITE setRequestingCompletionEnabled)
-    Q_PROPERTY(int autoReconnectInterval READ autoReconnectInterval WRITE setAutoReconnectInterval)
+    Q_PROPERTY(int autoReconnectInterval READ autoReconnectInterval WRITE setAutoReconnectInterval NOTIFY autoReconnectIntervalChanged)
     Q_PROPERTY(unsigned int autoReconnectTries READ autoReconnectTries)
     Q_PROPERTY(int trafficPollInterval READ trafficPollInterval WRITE setTrafficPollInterval)
     Q_PROPERTY(int devStatsPollInterval READ devStatsPollInterval WRITE setDevStatsPollInterval)
     Q_PROPERTY(bool recordFileChanges READ recordFileChanges WRITE setRecordFileChanges)
     Q_PROPERTY(int requestTimeout READ requestTimeout WRITE setRequestTimeout)
     Q_PROPERTY(int longPollingTimeout READ longPollingTimeout WRITE setLongPollingTimeout)
+    Q_PROPERTY(int diskEventLimit READ diskEventLimit WRITE setDiskEventLimit)
     Q_PROPERTY(QString myId READ myId NOTIFY myIdChanged)
     Q_PROPERTY(QString tilde READ tilde NOTIFY tildeChanged)
     Q_PROPERTY(QString pathSeparator READ pathSeparator NOTIFY tildeChanged)
@@ -153,25 +161,49 @@ class LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConnection : public QObject {
     Q_PROPERTY(QString lastSyncedFile READ lastSyncedFile)
     Q_PROPERTY(QString syncthingVersion READ syncthingVersion)
     Q_PROPERTY(CppUtilities::DateTime lastSyncTime READ lastSyncTime)
+#ifndef QT_NO_SSL
     Q_PROPERTY(QList<QSslError> expectedSslErrors READ expectedSslErrors)
+#endif
     Q_PROPERTY(std::vector<const SyncthingDev *> connectedDevices READ connectedDevices)
     Q_PROPERTY(QStringList directoryIds READ directoryIds)
     Q_PROPERTY(QStringList deviceIds READ deviceIds)
     Q_PROPERTY(QJsonObject rawConfig READ rawConfig NOTIFY newConfig)
     Q_PROPERTY(bool useDeprecatedRoutes READ isUsingDeprecatedRoutes WRITE setUseDeprecatedRoutes)
     Q_PROPERTY(bool pausingOnMeteredConnection READ isPausingOnMeteredConnection WRITE setPausingOnMeteredConnection)
+    Q_PROPERTY(bool insecure READ isInsecure WRITE setInsecure)
 
 public:
     explicit SyncthingConnection(const QString &syncthingUrl = QStringLiteral("http://localhost:8080"), const QByteArray &apiKey = QByteArray(),
         SyncthingConnectionLoggingFlags loggingFlags = SyncthingConnectionLoggingFlags::FromEnvironment, QObject *parent = nullptr);
     ~SyncthingConnection() override;
 
+    /// \brief The QueryResult struct is used to return the reply and associated signal/slot-connection of certain requests.
     struct QueryResult {
         QNetworkReply *reply = nullptr;
         QMetaObject::Connection connection;
     };
 
-    // getter/setter for
+    /// \brief The PollingFlags enum class specifies what information the connection is supposed to request/process.
+    enum class PollingFlags {
+        None, /**< only initial state is queried, no events are consumed to keep it up to date */
+        MainEvents = (1 << 0), /**< most important events are requested/processed to keep folder and device information up to date */
+        DiskEvents = (1 << 1), /**< events to emit the fileChanged() signal are requested/processed (used to show recent changed in the UI) */
+        DownloadProgress
+        = (1 << 2), /**< events to emit the downloadProgressChanged() signal are requested/processed (used to show downloads in the UI) */
+        RemoteIndexUpdated = (1
+            << 3), /**< requests the completion for the relevant folder/device again on `RemoteIndexUpdated` events (normally not required as `FolderCompletion` events contain this information as well) */
+        ItemFinished = (1
+            << 4), /**< processes `ItemFinished` events to update errors and list file information of folders (normally not required as calls to requestDirStatistics() on `StateChanged` events cover this) */
+        TrafficStatistics = (1 << 5), /**< polls for traffic statistics according to trafficPollInterval() */
+        DeviceStatistics = (1 << 6), /**< polls for device statistics according to devStatsPollInterval() */
+        Errors = (1 << 7), /**< polls for errors according to errorsPollInterval() */
+        All = MainEvents | DiskEvents | DownloadProgress | TrafficStatistics | DeviceStatistics
+            | Errors, /**< all events the SyncthingConnection class can make use of are requested/processed, this excludes redundant events */
+        NormalEvents
+        = MainEvents | DownloadProgress | RemoteIndexUpdated | ItemFinished, /**< events requested via the long-poling API by requestEvents() */
+    };
+
+    // getter/setter for various properties
     const QString &syncthingUrl() const;
     void setSyncthingUrl(const QString &url);
     bool isLocal() const;
@@ -180,8 +212,11 @@ public:
     const QString &user() const;
     const QString &password() const;
     void setCredentials(const QString &user, const QString &password);
+    Q_INVOKABLE QUrl makeUrlWithCredentials() const;
     bool isUsingDeprecatedRoutes() const;
     void setUseDeprecatedRoutes(bool useLegacyRoutes);
+    PollingFlags pollingFlags() const;
+    void setPollingFlags(PollingFlags flags);
 
     // getter for the status of the connection to Syncthing and of Syncthing itself
     SyncthingStatus status() const;
@@ -196,7 +231,7 @@ public:
     bool isConnecting() const;
     bool hasPendingRequests() const;
     bool hasPendingRequestsIncludingEvents() const;
-    bool hasUnreadNotifications() const;
+    bool hasErrors() const;
     bool hasOutOfSyncDirs() const;
 
     // getter/setter to configure connection behavior
@@ -218,14 +253,19 @@ public:
     void setRequestTimeout(int requestTimeout);
     int longPollingTimeout() const;
     void setLongPollingTimeout(int longPollingTimeout);
+    int diskEventLimit() const;
+    void setDiskEventLimit(int diskEventLimit);
     bool isPausingOnMeteredConnection() const;
     void setPausingOnMeteredConnection(bool pausingOnMeteredConnection);
+    bool isInsecure() const;
+    void setInsecure(bool insecure);
 
     // getter for information retrieved from Syncthing
     const QString &configDir() const;
     const QString &myId() const;
     const QString &tilde() const;
     const QString &pathSeparator() const;
+    Q_INVOKABLE QString substituteTilde(const QString &path) const;
     std::uint64_t totalIncomingTraffic() const;
     std::uint64_t totalOutgoingTraffic() const;
     double totalIncomingRate() const;
@@ -233,6 +273,7 @@ public:
     static constexpr std::uint64_t unknownTraffic = std::numeric_limits<std::uint64_t>::max();
     const std::vector<SyncthingDir> &dirInfo() const;
     const std::vector<SyncthingDev> &devInfo() const;
+    const std::vector<SyncthingError> &errors() const;
     SyncthingOverallDirStatistics computeOverallDirStatistics() const;
     const QString &lastSyncedFile() const;
     CppUtilities::DateTime lastSyncTime() const;
@@ -253,12 +294,17 @@ public:
     const SyncthingDev *findDevInfo(const QString &devId, int &row) const;
     SyncthingDev *findDevInfoByName(const QString &devName, int &row);
 
+#ifndef QT_NO_SSL
     const QList<QSslError> &expectedSslErrors() const;
+#endif
 
 public Q_SLOTS:
+#ifndef QT_NO_SSL
     bool loadSelfSignedCertificate(const QUrl &url = QUrl());
     void clearSelfSignedCertificate();
+#endif
     bool applySettings(Data::SyncthingConnectionSettings &connectionSettings);
+    void applyRawConfig();
 
     // methods to initiate/close connection
     void connect();
@@ -283,7 +329,6 @@ public Q_SLOTS:
     void rescanAllDirs();
     void restart();
     void shutdown();
-    void considerAllNotificationsRead();
 
     // methods to GET or POST information from/to Syncthing
     void requestConfig();
@@ -315,9 +360,13 @@ public:
     QueryResult setIgnores(const QString &dirId, const SyncthingIgnores &ignores, std::function<void(QString &&)> &&callback);
 
 Q_SIGNALS:
+    void syncthingUrlChanged(const QString &newUrl);
+    void autoReconnectIntervalChanged(int autoReconnectInterval);
     void newConfig(const QJsonObject &rawConfig);
-    void newDirs(const std::vector<SyncthingDir> &dirs);
-    void newDevices(const std::vector<SyncthingDev> &devs);
+    void newDirs(const std::vector<Data::SyncthingDir> &dirs);
+    void newDevices(const std::vector<Data::SyncthingDev> &devs);
+    void newErrors(const std::vector<Data::SyncthingError> &errors);
+    void beforeNewErrors(const std::vector<Data::SyncthingError> &oldErrors, const std::vector<Data::SyncthingError> &newErrors);
     void newConfigApplied();
     void newEvents(const QJsonArray &events);
     void allEventsProcessed();
@@ -346,10 +395,11 @@ Q_SIGNALS:
     void directoryResumeTriggered(const QStringList &dirIds);
     void restartTriggered();
     void shutdownTriggered();
-    void logAvailable(const std::vector<SyncthingLogEntry> &logEntries);
+    void logAvailable(const std::vector<Data::SyncthingLogEntry> &logEntries);
     void qrCodeAvailable(const QString &text, const QByteArray &qrCodeData);
     void overrideTriggered(const QString &dirId);
     void revertTriggered(const QString &dirId);
+    void hasOutOfSyncDirsChanged();
 
 private Q_SLOTS:
     // handler to evaluate results from request...() methods
@@ -358,7 +408,6 @@ private Q_SLOTS:
     void readDevs(const QJsonArray &devs);
     void readStatus();
     void concludeReadingConfigAndStatus();
-    void concludeConnection();
     void readConnections();
     void readDirStatistics();
     void readDeviceStatistics();
@@ -371,7 +420,6 @@ private Q_SLOTS:
     void readDownloadProgressEvent(const QJsonObject &eventData);
     void readDirEvent(SyncthingEventId eventId, CppUtilities::DateTime eventTime, const QString &eventType, const QJsonObject &eventData);
     void readDeviceEvent(SyncthingEventId eventId, CppUtilities::DateTime eventTime, const QString &eventType, const QJsonObject &eventData);
-    void readItemStarted(SyncthingEventId eventId, CppUtilities::DateTime eventTime, const QJsonObject &eventData);
     void readItemFinished(SyncthingEventId eventId, CppUtilities::DateTime eventTime, const QJsonObject &eventData);
     void readFolderErrors(
         SyncthingEventId eventId, CppUtilities::DateTime eventTime, const QJsonObject &eventData, Data::SyncthingDir &dirInfo, int index);
@@ -411,20 +459,21 @@ private Q_SLOTS:
     void continueConnecting();
     void continueReconnecting();
     void autoReconnect();
-    void setStatus(Data::SyncthingStatus status);
-    void emitNotification(CppUtilities::DateTime when, const QString &message);
+    bool setStatus(Data::SyncthingStatus status);
     void emitError(const QString &message, const QJsonParseError &jsonError, QNetworkReply *reply, const QByteArray &response = QByteArray());
     void emitError(const QString &message, Data::SyncthingErrorCategory category, QNetworkReply *reply);
     void emitError(const QString &message, QNetworkReply *reply);
     void emitMyIdChanged(const QString &newId);
     void emitTildeChanged(const QString &newTilde, const QString &newPathSeparator);
-    void emitDirStatisticsChanged();
     void handleFatalConnectionError();
     void handleAdditionalRequestCanceled();
+#ifndef QT_NO_SSL
     void handleSslErrors(const QList<QSslError> &errors);
+#endif
     void handleRedirection(const QUrl &url);
     void handleMeteredConnection();
     void recalculateStatus();
+    void invalidateHasOutOfSyncDirs();
 
 private:
     // handler to evaluate results from request...() methods
@@ -433,6 +482,14 @@ private:
     void readSetIgnores(const QString &dirId, std::function<void(QString &&)> &&callback);
 
     // internal helper methods
+    enum class StatusRecomputation {
+        None,
+        Status = (1 << 0),
+        OutOfSyncDirs = (1 << 1),
+        DirStats = (1 << 2),
+        StatusAndOutOfSyncDirs = Status | OutOfSyncDirs
+    };
+    void concludeConnection(StatusRecomputation flags);
     struct Reply {
         QNetworkReply *reply;
         QByteArray response;
@@ -454,6 +511,7 @@ private:
     QString configPath() const;
     QByteArray changeConfigVerb() const;
     QString folderErrorsPath() const;
+    bool checkConnectionConfiguration();
 
     QString m_syncthingUrl;
     QByteArray m_apiKey;
@@ -467,8 +525,12 @@ private:
     bool m_keepPolling;
     bool m_abortingAllRequests;
     bool m_connectionAborted;
+    bool m_abortingToConnect;
     bool m_abortingToReconnect;
     bool m_requestCompletion;
+    QString m_eventMask;
+    PollingFlags m_pollingFlags;
+    StatusRecomputation m_statusRecomputationFlags;
     SyncthingEventId m_lastEventId;
     SyncthingEventId m_lastDiskEventId;
     QTimer m_trafficPollTimer;
@@ -478,6 +540,7 @@ private:
     unsigned int m_autoReconnectTries;
     int m_requestTimeout;
     int m_longPollingTimeout;
+    int m_diskEventLimit;
     QString m_configDir;
     QString m_myId;
     QString m_tilde;
@@ -497,13 +560,14 @@ private:
     QNetworkReply *m_diskEventsReply;
     QNetworkReply *m_logReply;
     QList<QNetworkReply *> m_otherReplies;
-    bool m_unreadNotifications;
+    mutable std::optional<bool> m_hasOutOfSyncDirs;
     bool m_hasConfig;
     bool m_hasStatus;
     bool m_hasEvents;
     bool m_hasDiskEvents;
     std::vector<SyncthingDir> m_dirs;
     std::vector<SyncthingDev> m_devs;
+    std::vector<SyncthingError> m_errors;
     QStringList m_devsPausedDueToMeteredConnection;
     SyncthingEventId m_lastConnectionsUpdateEvent;
     CppUtilities::DateTime m_lastConnectionsUpdateTime;
@@ -514,19 +578,21 @@ private:
     QString m_lastFileName;
     QString m_syncthingVersion;
     bool m_lastFileDeleted;
+#ifndef QT_NO_SSL
     QString m_certificatePath;
     QString m_dynamicallyDeterminedCertificatePath;
     QDateTime m_certificateLastModified;
     QList<QSslError> m_expectedSslErrors;
     QSslCertificate m_certFromLastSslError;
+#endif
     QJsonObject m_rawConfig;
-    bool m_dirStatsAltered;
     bool m_recordFileChanges;
     bool m_useDeprecatedRoutes;
     bool m_pausingOnMeteredConnection;
 #ifdef SYNCTHINGCONNECTION_SUPPORT_METERED
     bool m_handlingMeteredConnectionInitialized;
 #endif
+    bool m_insecure;
 };
 
 /*!
@@ -542,7 +608,9 @@ inline const QString &SyncthingConnection::syncthingUrl() const
  */
 inline void SyncthingConnection::setSyncthingUrl(const QString &url)
 {
-    m_syncthingUrl = url;
+    if (m_syncthingUrl != url) {
+        emit syncthingUrlChanged(m_syncthingUrl = url);
+    }
 }
 
 /*!
@@ -607,12 +675,24 @@ inline void SyncthingConnection::setUseDeprecatedRoutes(bool useDeprecatedRoutes
     m_useDeprecatedRoutes = useDeprecatedRoutes;
 }
 
+/*!
+ * \brief Returns what kind of events are polled for.
+ */
+inline SyncthingConnection::PollingFlags SyncthingConnection::pollingFlags() const
+{
+    return m_pollingFlags;
+}
+
 /*!
  * \brief Returns the string representation of the current status().
  */
 inline QString SyncthingConnection::statusText() const
 {
-    return statusText(m_status);
+    auto text = m_status == SyncthingStatus::Disconnected && !isAborted() && hasPendingRequests() ? tr("connecting") : statusText(m_status);
+    if (m_autoReconnectTimer.isActive() && m_autoReconnectTimer.interval()) {
+        text += tr(", re-connect attempt every %1 ms").arg(m_autoReconnectTimer.interval());
+    }
+    return text;
 }
 
 /*!
@@ -669,12 +749,12 @@ inline bool SyncthingConnection::hasPendingRequests() const
 }
 
 /*!
- * \brief Returns whether there are unread notifications available.
- * \remarks This flag is set to true when new notifications become available. It can be unset again by calling considerAllNotificationsRead().
+ * \brief Returns whether there are errors (notifications) available.
+ * \remarks This flag is set to true when new notifications become available.
  */
-inline bool SyncthingConnection::hasUnreadNotifications() const
+inline bool SyncthingConnection::hasErrors() const
 {
-    return m_unreadNotifications;
+    return !m_errors.empty();
 }
 
 /*!
@@ -695,25 +775,6 @@ inline void SyncthingConnection::setRequestingCompletionEnabled(bool requestingC
     m_requestCompletion = requestingCompletionEnabled;
 }
 
-/*!
- * \brief Internally called to emit the notification with the specified \a message.
- * \remarks Ensures the unread notifications flag is set.
- */
-inline void SyncthingConnection::emitNotification(CppUtilities::DateTime when, const QString &message)
-{
-    m_unreadNotifications = true;
-    emit newNotification(when, message);
-}
-
-/*!
- * \brief Considers all notifications as read; hence might trigger a status update.
- */
-inline void SyncthingConnection::considerAllNotificationsRead()
-{
-    m_unreadNotifications = false;
-    requestClearingErrors();
-}
-
 /*!
  * \brief Returns the interval for polling traffic status (which can not be received via event API) in milliseconds.
  * \remarks For default value see SyncthingConnectionSettings. Zero means polling is disabled.
@@ -804,6 +865,7 @@ inline void SyncthingConnection::setAutoReconnectInterval(int interval)
         m_autoReconnectTimer.stop();
     }
     m_autoReconnectTimer.setInterval(interval);
+    emit autoReconnectIntervalChanged(interval);
 }
 
 /*!
@@ -862,6 +924,28 @@ inline void SyncthingConnection::setLongPollingTimeout(int longPollingTimeout)
     m_longPollingTimeout = longPollingTimeout;
 }
 
+/*!
+ * \brief Returns the limit for requestDiskEvents().
+ * \remarks
+ * The limit is used when requestDiskEvents() is invoked to establish a connection. When invoking
+ * requestDiskEvents() manually the limit is passed as first argument.
+ */
+inline int SyncthingConnection::diskEventLimit() const
+{
+    return m_diskEventLimit;
+}
+
+/*!
+ * \brief Sets the limit for requestDiskEvents().
+ * \remarks
+ * The limit is used when requestDiskEvents() is invoked to establish a connection. When invoking
+ * requestDiskEvents() manually the limit is passed as first argument.
+ */
+inline void SyncthingConnection::setDiskEventLimit(int diskEventLimit)
+{
+    m_diskEventLimit = diskEventLimit;
+}
+
 /*!
  * \brief Returns whether to pause all devices on metered connections.
  */
@@ -870,6 +954,23 @@ inline bool SyncthingConnection::isPausingOnMeteredConnection() const
     return m_pausingOnMeteredConnection;
 }
 
+/*!
+ * \brief Returns whether any certificate errors will be ignored.
+ * \remarks This will only ever be the case when this has been configured via setInsecure().
+ */
+inline bool SyncthingConnection::isInsecure() const
+{
+    return m_insecure;
+}
+
+/*!
+ * \brief Sets whether any certificate errors will be ignored.
+ */
+inline void SyncthingConnection::setInsecure(bool insecure)
+{
+    m_insecure = insecure;
+}
+
 /*!
  * \brief Returns what information is considered to compute the overall status returned by status().
  */
@@ -981,6 +1082,14 @@ inline const std::vector<SyncthingDev> &SyncthingConnection::devInfo() const
     return m_devs;
 }
 
+/*!
+ * \brief Returns all currently present errors.
+ */
+inline const std::vector<SyncthingError> &Data::SyncthingConnection::errors() const
+{
+    return m_errors;
+}
+
 /*!
  * \brief Computes overall directory statistics based on the currently available directory information.
  */
@@ -1029,6 +1138,7 @@ inline const QString &SyncthingConnection::syncthingVersion() const
     return m_syncthingVersion;
 }
 
+#ifndef QT_NO_SSL
 /*!
  * \brief Returns a list of all expected certificate errors. This is meant to allow self-signed certificates.
  * \remarks This list is updated via loadSelfSignedCertificate().
@@ -1037,6 +1147,7 @@ inline const QList<QSslError> &SyncthingConnection::expectedSslErrors() const
 {
     return m_expectedSslErrors;
 }
+#endif
 
 /*!
  * \brief Returns the raw Syncthing configuration.
@@ -1071,4 +1182,7 @@ inline const SyncthingDev *SyncthingConnection::findDevInfo(const QString &devId
 
 Q_DECLARE_METATYPE(Data::SyncthingLogEntry)
 
+CPP_UTILITIES_MARK_FLAG_ENUM_CLASS(Data, Data::SyncthingConnection::StatusRecomputation)
+CPP_UTILITIES_MARK_FLAG_ENUM_CLASS(Data, Data::SyncthingConnection::PollingFlags)
+
 #endif // SYNCTHINGCONNECTION_H
