@@ -11,6 +11,7 @@
 #include <QSslError>
 #include <QString>
 
+QT_FORWARD_DECLARE_CLASS(QJsonObject)
 QT_FORWARD_DECLARE_CLASS(QSslCertificate)
 
 namespace Data {
@@ -48,14 +49,21 @@ struct LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConnectionSettings {
     int reconnectInterval = defaultReconnectInterval;
     int requestTimeout = defaultRequestTimeout;
     int longPollingTimeout = defaultLongPollingTimeout;
+    int diskEventLimit = defaultDiskEventLimit;
+#ifndef QT_NO_SSL
     QString httpsCertPath;
     QDateTime httpCertLastModified;
     QList<QSslError> expectedSslErrors;
+#endif
     SyncthingStatusComputionFlags statusComputionFlags = SyncthingStatusComputionFlags::Default;
     bool autoConnect = false;
     bool pauseOnMeteredConnection = false;
+#ifndef QT_NO_SSL
     static QList<QSslError> compileSslErrors(const QSslCertificate &trustedCert);
     bool loadHttpsCert();
+#endif
+    void storeToJson(QJsonObject &object);
+    bool loadFromJson(const QJsonObject &object);
 
     static constexpr int defaultTrafficPollInterval = 5000;
     static constexpr int defaultDevStatusPollInterval = 60000;
@@ -63,6 +71,7 @@ struct LIB_SYNCTHING_CONNECTOR_EXPORT SyncthingConnectionSettings {
     static constexpr int defaultReconnectInterval = 30000;
     static constexpr int defaultRequestTimeout = 0;
     static constexpr int defaultLongPollingTimeout = 0;
+    static constexpr int defaultDiskEventLimit = 200;
 };
 } // namespace Data
 
