@@ -4,42 +4,42 @@
 <context>
     <name>Data::SyncthingConnection</name>
     <message>
-        <location filename="../syncthingconnection.cpp" line="177"/>
+        <location filename="../syncthingconnection.cpp" line="180"/>
         <source>disconnected</source>
         <translation>Verbindung getrennt</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="179"/>
+        <location filename="../syncthingconnection.cpp" line="182"/>
         <source>reconnecting</source>
-        <translation>Verbindung wird hergestellt</translation>
+        <translation>Verbindung wird wiederhergestellt</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="181"/>
+        <location filename="../syncthingconnection.cpp" line="184"/>
         <source>connected</source>
         <translation>verbunden</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="183"/>
+        <location filename="../syncthingconnection.cpp" line="186"/>
         <source>connected, scanning</source>
         <translation>verbunden, scannt</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="185"/>
+        <location filename="../syncthingconnection.cpp" line="188"/>
         <source>connected, paused</source>
         <translation>verbunden, pausiert</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="187"/>
+        <location filename="../syncthingconnection.cpp" line="190"/>
         <source>connected, synchronizing</source>
         <translation>verbunden, am Synchronisieren</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="189"/>
+        <location filename="../syncthingconnection.cpp" line="192"/>
         <source>connected, remote not in sync</source>
         <translation>verbunden, entferntes Gerät nicht synchronisiert</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="799"/>
+        <location filename="../syncthingconnection.cpp" line="938"/>
         <source>Unable to parse timestamp &quot;%1&quot; (%2): %3</source>
         <translation>Fehler beim Parsen des Zeitstempels &quot;%1&quot; (Kontext: &quot;%2&quot;): %3</translation>
     </message>
@@ -48,243 +48,252 @@
         <translation type="vanished">verbunden, nicht synchronisiert</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="191"/>
+        <location filename="../syncthingconnection.cpp" line="194"/>
         <source>unknown</source>
         <translation>Verbindungsstatus unbekannt</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="341"/>
-        <location filename="../syncthingconnection.cpp" line="531"/>
+        <location filename="../syncthingconnection.cpp" line="465"/>
         <source>Connection configuration is insufficient.</source>
         <translation>Verbindungskonfiguration is ungenügend</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="533"/>
+        <location filename="../syncthingconnection_requests.cpp" line="551"/>
         <source>Unable to rescan: No folder ID specified.</source>
         <translation>Fehler beim Anfordern eines Scans: keine Ordner-ID angegeben.</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="350"/>
+        <location filename="../syncthingconnection_requests.cpp" line="368"/>
         <source>Unable to pause/resume a devices when not connected</source>
         <translation>Fehler beim Anfordern Ordner zu Pausieren/Fortzusetzen</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="465"/>
+        <location filename="../syncthingconnection_requests.cpp" line="483"/>
         <source>Unable to pause/resume a folders when not connected</source>
         <translation>Fehler beim Anfordern Gerät zu Pausieren/Fortzusetzen</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1465"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1511"/>
         <source>Unable to request QR-Code: </source>
         <translation>Fehler beim Abfragen des QR-Codes: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1498"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1544"/>
         <source>Unable to parse Syncthing log: </source>
         <translation>Fehler beim Auslesen des Syncthing-Logs: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1515"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1561"/>
         <source>Unable to request Syncthing log: </source>
         <translation>Fehler beim Abfragen des Syncthing-Logs: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="872"/>
+        <location filename="../syncthingconnection.cpp" line="1011"/>
         <source>Unable to locate certificate used by Syncthing.</source>
         <translation>Das SSL-Zertifikat von Syncthing kann nicht gefunden werden.</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="878"/>
+        <location filename="../syncthingconnection.cpp" line="1017"/>
         <source>Unable to load certificate used by Syncthing.</source>
         <translation>Das SSL-Zertifikat von Syncthing kann nicht ausgelesen werden.</translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="688"/>
+        <location filename="../syncthingconnection_requests.cpp" line="710"/>
         <source>Unable to parse Syncthing config: </source>
         <translation>Fehler beim Auslesen der Syncthing-Konfiguration: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="710"/>
+        <location filename="../syncthingconnection_requests.cpp" line="727"/>
         <source>Unable to request Syncthing config: </source>
         <translation>Fehler beim Abfragen der Syncthing-Konfiguration: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="839"/>
+        <location filename="../syncthingconnection_requests.cpp" line="858"/>
         <source>Unable to parse Syncthing status: </source>
         <translation>Fehler beim Auslesen des Syncthing-Status: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="858"/>
+        <location filename="../syncthingconnection_requests.cpp" line="877"/>
         <source>Unable to request Syncthing status: </source>
         <translation>Fehler beim Abfragen des Syncthing-Status: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="906"/>
+        <location filename="../syncthingconnection_requests.cpp" line="925"/>
         <source>Unable to parse connections: </source>
         <translation>Fehler beim Auslesen der Verbindungen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="983"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1008"/>
         <source>Unable to request connections: </source>
         <translation>Fehler beim Abfragen der Verbindungen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1081"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1119"/>
         <source>Unable to parse folder statistics: </source>
         <translation>Fehler beim Auslesen der Ordnerstatistiken: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1132"/>
-        <location filename="../syncthingconnection_requests.cpp" line="1190"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1170"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1232"/>
         <source>Unable to request folder statistics: </source>
         <translation>Fehler beim Abfragen der Ordnerstatistiken: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1361"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1407"/>
         <source>Unable to parse device statistics: </source>
         <translation>Fehler beim Auslesen der Gerätestatistiken: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1388"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1434"/>
         <source>Unable to request device statistics: </source>
         <translation>Fehler beim Abfragen der Gerätestatistiken: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1021"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1047"/>
         <source>Unable to parse errors: </source>
         <translation>Fehler beim Auslesen der Syncthing-Fehlermeldungen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1049"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1087"/>
         <source>Unable to request errors: </source>
         <translation>Fehler beim Abfragen der Syncthing-Fehlermeldungen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="654"/>
+        <location filename="../syncthingconnection_requests.cpp" line="676"/>
         <source>Unable to request clearing errors: </source>
         <translation>Fehler beim Löschen der Fehlermeldungen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="2021"/>
+        <location filename="../syncthingconnection_requests.cpp" line="2099"/>
         <source>Unable to parse Syncthing events: </source>
         <translation>Fehler beim Auslesen der Syncthing-Ereignisse: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="2048"/>
+        <location filename="../syncthingconnection_requests.cpp" line="2128"/>
         <source>Unable to request Syncthing events: </source>
         <translation>Fehler beim Abfragen der Syncthing-Ereignisse: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1845"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1891"/>
         <source>Unable to post config: </source>
         <translation>Fehler beim Senden der neuen Konfiguration: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="563"/>
+        <location filename="../syncthingconnection_requests.cpp" line="581"/>
         <source>Unable to request rescan: </source>
         <translation>Fehler beim Anfordern eines Ordner-Rescans: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="398"/>
+        <location filename="../syncthingconnection_requests.cpp" line="416"/>
         <source>Unable to request device pause/resume: </source>
         <translation>Fehler beim Anfordern Gerät zu Pausieren/Fortzusetzen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="502"/>
+        <location filename="../syncthingconnection_requests.cpp" line="520"/>
         <source>Unable to request folder pause/resume: </source>
         <translation>Fehler beim Anfordern Ordner zu Pausieren/Fortzusetzen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="594"/>
+        <location filename="../syncthingconnection_requests.cpp" line="612"/>
         <source>Unable to request restart: </source>
         <translation>Fehler beim Anfordern eines Neustarts: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="623"/>
+        <location filename="../syncthingconnection_requests.cpp" line="641"/>
         <source>Unable to request shutdown: </source>
         <translation>Fehler beim Anfordern Syncthing zu beenden: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1175"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1213"/>
         <source>Unable to parse status for folder %1: </source>
         <translation>Fehler beim Auslesen des Status von Ordner %1: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1238"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1280"/>
         <source>Unable to parse pull errors for folder %1: </source>
         <translation>Fehler beim Auslesen der Fehler von Ordner %1: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1248"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1294"/>
         <source>Unable to request pull errors for folder %1: </source>
         <translation>Fehler beim Anfordern der Fehler von Ordner %1: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1314"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1360"/>
         <source>Unable to parse completion for device/folder %1/%2: </source>
         <translation>Fehler beim Auslesen des Fortschrittes von Ordner %1/%2: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1329"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1375"/>
         <source>Unable to request completion for device/folder %1/%2: </source>
         <translation>Fehler beim Anfordern des Fortschrittes von Ordner %1/%2: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1416"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1462"/>
         <source>Unable to parse version: </source>
         <translation>Fehler beim Auslesen der Syncthing-Version: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1430"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1476"/>
         <source>Unable to request version: </source>
         <translation>Fehler beim Anfordern der Syncthing-Version: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1548"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1594"/>
         <source>Unable to request directory override: </source>
         <translation>Fehler Überschreiben: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1581"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1627"/>
         <source>Unable to request directory revert: </source>
         <translation>Fehler beim Zurücksetzen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1713"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1759"/>
         <source>Unable to parse response for browsing &quot;%1&quot;: </source>
         <translation>Fehler beim Auslesen der Inhalte des Ordners &quot;%1&quot;: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1727"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1773"/>
         <source>Unable to browse &quot;%1&quot;: </source>
         <translation>Fehler beim Durchsuchen des Ordners &quot;%1&quot;: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1751"/>
-        <location filename="../syncthingconnection_requests.cpp" line="1775"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1797"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1821"/>
         <source>Unable to query ignore patterns of &quot;%1&quot;: </source>
-        <translation type="unfinished"></translation>
+        <translation>Fehler beim Abrufen des Ignoriermusters von &quot;%1&quot;: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="1801"/>
+        <location filename="../syncthingconnection_requests.cpp" line="1847"/>
         <source>Unable to change ignore patterns of &quot;%1&quot;: </source>
-        <translation type="unfinished"></translation>
+        <translation>Fehler beim Ändern des Ignoriermusters von &quot;%1&quot;: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="2629"/>
+        <location filename="../syncthingconnection_requests.cpp" line="2726"/>
         <source>Unable to parse disk events: </source>
         <translation>Fehler beim Auslesen der letzten Änderungen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection_requests.cpp" line="2652"/>
+        <location filename="../syncthingconnection_requests.cpp" line="2751"/>
         <source>Unable to request disk events: </source>
         <translation>Fehler beim Anfordern der letzten Änderungen: </translation>
     </message>
     <message>
-        <location filename="../syncthingconnection.cpp" line="1071"/>
+        <location filename="../syncthingconnection.cpp" line="1218"/>
         <source>at offset %1</source>
         <translation>bei Zeichen %1</translation>
     </message>
+    <message>
+        <location filename="../syncthingconnection.h" line="691"/>
+        <source>connecting</source>
+        <translation>Verbindung wird hergestellt</translation>
+    </message>
+    <message>
+        <location filename="../syncthingconnection.h" line="693"/>
+        <source>, re-connect attempt every %1 ms</source>
+        <translation>, Verbindungsversuch alle %1 ms</translation>
+    </message>
 </context>
 <context>
     <name>Data::SyncthingNotifier</name>
@@ -341,27 +350,27 @@
 <context>
     <name>Data::SyncthingService</name>
     <message>
-        <location filename="../syncthingservice.cpp" line="394"/>
+        <location filename="../syncthingservice.cpp" line="378"/>
         <source>start unit</source>
         <translation>Starten der Unit</translation>
     </message>
     <message>
-        <location filename="../syncthingservice.cpp" line="396"/>
+        <location filename="../syncthingservice.cpp" line="380"/>
         <source>stop unit</source>
         <translation>Stoppen der Unit</translation>
     </message>
     <message>
-        <location filename="../syncthingservice.cpp" line="411"/>
+        <location filename="../syncthingservice.cpp" line="395"/>
         <source>enable unit</source>
         <translation>Aktivieren der Unit</translation>
     </message>
     <message>
-        <location filename="../syncthingservice.cpp" line="413"/>
+        <location filename="../syncthingservice.cpp" line="397"/>
         <source>disable unit</source>
         <translation>Deaktivieren der Unit</translation>
     </message>
     <message>
-        <location filename="../syncthingservice.cpp" line="423"/>
+        <location filename="../syncthingservice.cpp" line="407"/>
         <source>reload all unit files</source>
         <translation>Aktualisieren aller Unit-Dateien</translation>
     </message>
@@ -447,136 +456,267 @@
 <context>
     <name>SyncthingDev</name>
     <message>
-        <location filename="../syncthingdev.cpp" line="32"/>
         <source>paused</source>
-        <translation>pausiert</translation>
+        <translation type="vanished">pausiert</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdev.cpp" line="36"/>
+        <source>Paused</source>
+        <translation>Pausiert</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdev.cpp" line="39"/>
+        <source>Syncing (%1 %, %2)</source>
+        <translation>Synchronisiere (%1 %, %2)</translation>
     </message>
 </context>
 <context>
     <name>SyncthingDevStatus</name>
     <message>
-        <location filename="../syncthingdev.cpp" line="11"/>
         <source>unknown</source>
-        <translation>unbekannt</translation>
+        <translation type="vanished">unbekannt</translation>
     </message>
     <message>
-        <location filename="../syncthingdev.cpp" line="13"/>
         <source>disconnected</source>
-        <translation>getrennt</translation>
+        <translation type="vanished">getrennt</translation>
+    </message>
+    <message>
+        <source>this device</source>
+        <translation type="vanished">dieses Gerät</translation>
+    </message>
+    <message>
+        <source>idle</source>
+        <translation type="vanished">untätig</translation>
+    </message>
+    <message>
+        <source>synchronizing</source>
+        <translation type="vanished">synchronisiert</translation>
+    </message>
+    <message>
+        <source>out of sync</source>
+        <translation type="vanished">nicht synchronisiert</translation>
+    </message>
+    <message>
+        <source>rejected</source>
+        <translation type="vanished">zurückgewiesen</translation>
     </message>
     <message>
         <location filename="../syncthingdev.cpp" line="15"/>
-        <source>this device</source>
-        <translation>dieses Gerät</translation>
+        <source>Unknown</source>
+        <translation>Unbekannt</translation>
     </message>
     <message>
         <location filename="../syncthingdev.cpp" line="17"/>
-        <source>idle</source>
-        <translation>untätig</translation>
+        <source>Disconnected</source>
+        <translation>Getrennt</translation>
     </message>
     <message>
         <location filename="../syncthingdev.cpp" line="19"/>
-        <source>synchronizing</source>
-        <translation>synchronisiert</translation>
+        <source>This Device</source>
+        <translation>Dieses Gerät</translation>
     </message>
     <message>
         <location filename="../syncthingdev.cpp" line="21"/>
-        <source>out of sync</source>
-        <translation>nicht synchronisiert</translation>
+        <source>Idle</source>
+        <translation>Leerlauf</translation>
     </message>
     <message>
         <location filename="../syncthingdev.cpp" line="23"/>
-        <source>rejected</source>
-        <translation>zurückgewiesen</translation>
+        <source>Syncing</source>
+        <translation>Synchronisiere</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdev.cpp" line="25"/>
+        <source>Out of Sync</source>
+        <translation>Nicht synchronisiert</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdev.cpp" line="27"/>
+        <source>Rejected</source>
+        <translation>Zurückgewiesen</translation>
     </message>
 </context>
 <context>
     <name>SyncthingDir</name>
     <message>
-        <location filename="../syncthingdir.cpp" line="174"/>
         <source>paused</source>
-        <translation>pausiert</translation>
+        <translation type="vanished">pausiert</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="176"/>
         <source>unshared</source>
-        <translation>nicht geteilt</translation>
+        <translation type="vanished">nicht geteilt</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="180"/>
+        <source>Paused</source>
+        <translation>Pausiert</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="183"/>
+        <source>Unshared</source>
+        <translation>Ungeteilt</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="18"/>
+        <source>Unknown</source>
+        <translation>Unbekannt</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="195"/>
+        <source>Local Additions</source>
+        <translation>Lokal hinzugefügte Elemente</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="197"/>
+        <source>Unexpected Items</source>
+        <translation>Unerwartete Elemente</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="20"/>
+        <source>Up to Date</source>
+        <translation>Aktuell</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="22"/>
+        <source>Waiting to Scan</source>
+        <translation>Warten auf Scannen</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="205"/>
+        <source>Scanning (%1 %, %2)</source>
+        <translation>Scannen (%1 %, %2)</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="209"/>
+        <source>Scanning (%1 %)</source>
+        <translation>Scannen (%1 %)</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="24"/>
+        <source>Scanning</source>
+        <translation>Scannen</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="26"/>
+        <source>Waiting to Sync</source>
+        <translation>Warten auf die Synchronisation</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="28"/>
+        <source>Preparing to Sync</source>
+        <translation>Vorbereiten auf die Synchronisation</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="214"/>
+        <source>Syncing (%1 %)</source>
+        <translation>Synchronisiere (%1 %)</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="30"/>
+        <source>Syncing</source>
+        <translation>Synchronisiere</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="32"/>
+        <source>Cleaning Versions</source>
+        <translation>Versionen bereinigen</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="34"/>
+        <source>Waiting to Clean</source>
+        <translation>Warten auf Bereinigung</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="36"/>
+        <source>Out of Sync</source>
+        <translation>Nicht synchronisiert</translation>
     </message>
 </context>
 <context>
     <name>SyncthingDirStatus</name>
     <message>
-        <location filename="../syncthingdir.cpp" line="17"/>
         <source>unknown</source>
-        <translation>unbekannt</translation>
+        <translation type="vanished">unbekannt</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="19"/>
         <source>idle</source>
-        <translation>untätig</translation>
+        <translation type="vanished">untätig</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="23"/>
         <source>waiting to scan</source>
-        <translation>wartet aufs Scannen</translation>
+        <translation type="vanished">wartet aufs Scannen</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="21"/>
         <source>scanning</source>
-        <translation>scannt</translation>
+        <translation type="vanished">scannt</translation>
+    </message>
+    <message>
+        <source>up to date</source>
+        <translation type="vanished">aktuell</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="25"/>
         <source>waiting to sync</source>
-        <translation>wartet aufs Synchronisieren</translation>
+        <translation type="vanished">wartet aufs Synchronisieren</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="27"/>
         <source>preparing to sync</source>
-        <translation>bereitet Synchronisation vor</translation>
+        <translation type="vanished">bereitet Synchronisation vor</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="29"/>
         <source>synchronizing</source>
-        <translation>synchronisiert</translation>
+        <translation type="vanished">synchronisiert</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="31"/>
         <source>cleaning</source>
-        <translation>Versionen bereinigen</translation>
+        <translation type="vanished">Versionen bereinigen</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="33"/>
         <source>waiting to clean</source>
-        <translation>wartet auf Bereinigung</translation>
+        <translation type="vanished">wartet auf Bereinigung</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="35"/>
         <source>out of sync</source>
-        <translation>nicht synchronisiert</translation>
+        <translation type="vanished">nicht synchronisiert</translation>
     </message>
 </context>
 <context>
     <name>SyncthingDirType</name>
     <message>
-        <location filename="../syncthingdir.cpp" line="44"/>
         <source>unknown</source>
-        <translation>unbekannt</translation>
+        <translation type="vanished">unbekannt</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="46"/>
+        <location filename="../syncthingdir.cpp" line="45"/>
+        <source>Unknown</source>
+        <translation>Unbekannt</translation>
+    </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="47"/>
         <source>Send &amp; Receive</source>
         <translation>Senden &amp; Empfangen</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="48"/>
-        <source>Send only</source>
+        <location filename="../syncthingdir.cpp" line="49"/>
+        <source>Send Only</source>
         <translation>Nur senden</translation>
     </message>
     <message>
-        <location filename="../syncthingdir.cpp" line="50"/>
-        <source>Receive only</source>
+        <location filename="../syncthingdir.cpp" line="51"/>
+        <source>Receive Only</source>
         <translation>Nur empfangen</translation>
     </message>
+    <message>
+        <location filename="../syncthingdir.cpp" line="53"/>
+        <source>Receive Encrypted</source>
+        <translation>Empfange verschlüsselt</translation>
+    </message>
+    <message>
+        <source>Send only</source>
+        <translation type="vanished">Nur senden</translation>
+    </message>
+    <message>
+        <source>Receive only</source>
+        <translation type="vanished">Nur empfangen</translation>
+    </message>
 </context>
 </TS>
