@@ -6,25 +6,45 @@
 #include <syncthingconnector/syncthingconnection.h>
 #include <syncthingconnector/syncthingignorepattern.h>
 
+#include <QAction>
 #include <QFuture>
 #include <QFutureWatcher>
 #include <QHash>
+#include <QPixmap>
 #include <QSet>
 
 #include <map>
 #include <memory>
 #include <vector>
 
-QT_FORWARD_DECLARE_CLASS(QAction)
-
 class ModelTests;
 
 namespace Data {
 
+class LIB_SYNCTHING_MODEL_EXPORT RejectableAction : public QAction {
+    Q_OBJECT
+    Q_PROPERTY(bool needsConfirmation MEMBER needsConfirmation)
+
+public:
+    explicit RejectableAction(const QString &text, QObject *parent = nullptr)
+        : QAction(text, parent)
+    {
+    }
+
+    Q_INVOKABLE void dismiss()
+    {
+        needsConfirmation = true;
+    }
+    bool needsConfirmation = true;
+};
+
 class LIB_SYNCTHING_MODEL_EXPORT SyncthingFileModel : public SyncthingModel {
     Q_OBJECT
     Q_PROPERTY(bool hasIgnorePatterns READ hasIgnorePatterns)
-    Q_PROPERTY(bool selectionModeEnabled READ isSelectionModeEnabled WRITE setSelectionModeEnabled)
+    Q_PROPERTY(bool selectionModeEnabled READ isSelectionModeEnabled WRITE setSelectionModeEnabled NOTIFY selectionModeEnabledChanged)
+    Q_PROPERTY(bool recursiveSelectionEnabled READ isRecursiveSelectionEnabled WRITE setRecursiveSelectionEnabled)
+    Q_PROPERTY(QList<QAction *> selectionActions READ selectionActions NOTIFY selectionActionsChanged)
+    Q_PROPERTY(bool hasStagedChanges READ hasStagedChanges NOTIFY hasStagedChangesChanged)
 
 public:
     friend class ::ModelTests;
@@ -36,7 +56,9 @@ public:
         PathRole,
         Actions,
         ActionNames,
-        ActionIcons
+        ActionIcons,
+        DetailsRole,
+        CheckableRole,
     };
 
     explicit SyncthingFileModel(SyncthingConnection &connection, const SyncthingDir &dir, QObject *parent = nullptr);
@@ -61,12 +83,20 @@ public:
     void setSelectionModeEnabled(bool selectionModeEnabled);
     Q_INVOKABLE QString path(const QModelIndex &path) const;
     bool hasIgnorePatterns() const;
+    bool hasStagedChanges() const;
     const std::vector<SyncthingIgnorePattern> &presentIgnorePatterns() const;
+    SyncthingIgnores computeNewIgnorePatterns() const;
+    void editIgnorePatternsManually(const QString &ignorePatterns);
+    bool isRecursiveSelectionEnabled() const;
+    void setRecursiveSelectionEnabled(bool recursiveSelectionEnabled);
 
 Q_SIGNALS:
     void fetchQueueEmpty();
     void notification(const QString &type, const QString &message, const QString &details = QString());
     void actionNeedsConfirmation(QAction *action, const QString &message, const QString &diff = QString());
+    void selectionModeEnabledChanged(bool selectionModeEnabled);
+    void selectionActionsChanged();
+    void hasStagedChangesChanged(bool hasStagedChanged);
 
 private Q_SLOTS:
     void handleConfigInvalidated() override;
@@ -76,17 +106,28 @@ private Q_SLOTS:
     void handleLocalLookupFinished();
 
 private:
-    void setCheckState(const QModelIndex &index, Qt::CheckState checkState, bool recursively = true);
+    void setCheckState(const QModelIndex &index, Qt::CheckState checkState, bool recursively = false);
     void processFetchQueue(const QString &lastItemPath = QString());
     void queryIgnores();
+    void resetMatchingIgnorePatterns();
     void matchItemAgainstIgnorePatterns(SyncthingItem &item) const;
     void ignoreSelectedItems(bool ignore = true);
-    QString computeIgnorePatternDiff() const;
-    SyncthingIgnores computeNewIgnorePatterns() const;
+    QString computeIgnorePatternDiff();
+    QString availabilityNote(const SyncthingItem *item) const;
 
 private:
     using SyncthingItems = std::vector<std::unique_ptr<SyncthingItem>>;
-    using LocalLookupRes = std::shared_ptr<std::map<QString, SyncthingItem>>;
+    struct LocalItem;
+    using LocalItemMap = std::map<QString, LocalItem>;
+    struct LocalItem : public SyncthingItem {
+        LocalItemMap localChildren;
+        bool localChildrenPopulated = false;
+    };
+    using LocalLookupRes = std::shared_ptr<LocalItemMap>;
+    static void lookupDirLocally(const QDir &dir, SyncthingFileModel::LocalItemMap &items, int depth = 1);
+    static void markItemsFromDatabaseAsLocallyExisting(
+        std::vector<std::unique_ptr<SyncthingItem>> &items, SyncthingFileModel::LocalItemMap &localItems);
+    void insertLocalItems(const QModelIndex &refreshedIndex, SyncthingFileModel::LocalItemMap &localItems);
     struct QueryResult : SyncthingConnection::QueryResult {
         QString forPath;
         QFuture<LocalLookupRes> localLookup;
@@ -94,8 +135,9 @@ private:
         QueryResult &operator=(SyncthingConnection::QueryResult &&);
     };
     struct Change {
-        QStringList newLines;
-        bool append = false;
+        QStringList prepend;
+        QStringList append;
+        bool replace = false;
     };
 
     SyncthingConnection &m_connection;
@@ -109,9 +151,15 @@ private:
     QueryResult m_pendingRequest;
     QFutureWatcher<LocalLookupRes> m_localItemLookup;
     std::unique_ptr<SyncthingItem> m_root;
+    QString m_manuallyEditedIgnorePatterns;
+    QString m_ignoreAllByDefaultPattern;
     QChar m_pathSeparator;
+    mutable QPixmap m_statusIcons[4];
+    int m_columns;
     bool m_selectionMode;
     bool m_hasIgnorePatterns;
+    bool m_isIgnoringAllByDefault;
+    bool m_recursiveSelectionEnabled;
 };
 
 inline bool SyncthingFileModel::isSelectionModeEnabled() const
@@ -124,11 +172,26 @@ inline bool SyncthingFileModel::hasIgnorePatterns() const
     return m_hasIgnorePatterns;
 }
 
+inline bool SyncthingFileModel::hasStagedChanges() const
+{
+    return !m_stagedChanges.isEmpty();
+}
+
 inline const std::vector<SyncthingIgnorePattern> &SyncthingFileModel::presentIgnorePatterns() const
 {
     return m_presentIgnorePatterns;
 }
 
+inline bool SyncthingFileModel::isRecursiveSelectionEnabled() const
+{
+    return m_recursiveSelectionEnabled;
+}
+
+inline void SyncthingFileModel::setRecursiveSelectionEnabled(bool recursiveSelectionEnabled)
+{
+    m_recursiveSelectionEnabled = recursiveSelectionEnabled;
+}
+
 } // namespace Data
 
 #endif // DATA_SYNCTHINGFILEMODEL_H
