@@ -6,6 +6,7 @@
 #include "resources/../../tray/resources/config.h"
 
 #include <qtutilities/misc/compat.h>
+#include <qtutilities/misc/desktoputils.h>
 
 #include <qtforkawesome/icon.h>
 
@@ -243,7 +244,7 @@ StatusIconSettings::StatusIconSettings(const QString &str)
     : StatusIconSettings()
 {
     const auto parts = QtUtilities::splitRef(str, QChar(';'));
-    int index = 0;
+    auto index = int();
     for (auto *field :
         { &defaultColor, &errorColor, &warningColor, &idleColor, &scanningColor, &synchronizingColor, &pausedColor, &disconnectedColor }) {
         if (index >= parts.size()) {
@@ -276,6 +277,16 @@ QString StatusIconSettings::toString() const
     return res;
 }
 
+StatusIconSettings StatusIconSettings::forPalette(const QPalette &palette, const StatusIconSettings &otherSettings)
+{
+    auto settings = QtUtilities::isPaletteDark(palette) ? StatusIconSettings(StatusIconSettings::DarkTheme{})
+                                                        : StatusIconSettings(StatusIconSettings::BrightTheme{});
+    settings.defaultColor.foreground = settings.idleColor.foreground = palette.color(QPalette::Normal, QPalette::Text);
+    settings.renderSize = otherSettings.renderSize;
+    settings.strokeWidth = otherSettings.strokeWidth;
+    return settings;
+}
+
 StatusIcons::StatusIcons(const StatusIconSettings &settings)
     : disconnected(
           QIcon(renderSvgImage(makeSyncthingIcon(settings.disconnectedColor, StatusEmblem::None, settings.strokeWidth), settings.renderSize)))
@@ -323,6 +334,7 @@ IconManager::IconManager(const QPalette *palette)
     , m_trayIcons(m_statusIcons)
     , m_commonForkAwesomeIcons(
           m_forkAwesomeRenderer, (palette ? *palette : QGuiApplication::palette()).color(QPalette::Normal, QPalette::Text), QSize(64, 64))
+    , m_distinguishTrayIcons(false)
 {
 #ifdef __GNUC__
 #pragma GCC diagnostic push
@@ -336,8 +348,54 @@ IconManager::IconManager(const QPalette *palette)
 #endif
 }
 
+void IconManager::applySettings(
+    const StatusIconSettings *statusIconSettings, const StatusIconSettings *trayIconSettings, bool usePaletteForStatus, bool usePaletteForTray)
+{
+    static const auto defaultSettings = StatusIconSettings();
+    m_distinguishTrayIcons = trayIconSettings != nullptr;
+    if (usePaletteForStatus) {
+        m_paletteBasedSettingsForStatus = StatusIconSettings::forPalette(m_palette, statusIconSettings ? *statusIconSettings : defaultSettings);
+    } else {
+        m_paletteBasedSettingsForStatus.reset();
+    }
+    if (!m_distinguishTrayIcons) {
+        m_paletteBasedSettingsForTray = m_paletteBasedSettingsForStatus;
+    } else if (usePaletteForTray) {
+        m_paletteBasedSettingsForTray = StatusIconSettings::forPalette(m_palette, trayIconSettings ? *trayIconSettings : defaultSettings);
+    } else {
+        m_paletteBasedSettingsForTray.reset();
+    }
+    if (m_paletteBasedSettingsForStatus.has_value()) {
+        m_statusIcons = StatusIcons(m_paletteBasedSettingsForStatus.value());
+    } else if (statusIconSettings) {
+        m_statusIcons = StatusIcons(*statusIconSettings);
+    } else {
+        m_statusIcons = StatusIcons(defaultSettings);
+    }
+    if (m_paletteBasedSettingsForTray.has_value()) {
+        m_trayIcons = m_paletteBasedSettingsForTray.value();
+    } else if (trayIconSettings) {
+        m_trayIcons = StatusIcons(*trayIconSettings);
+    } else {
+        m_trayIcons = m_statusIcons;
+    }
+    emit statusIconsChanged(m_statusIcons, m_trayIcons);
+}
+
 void IconManager::setPalette(const QPalette &palette)
 {
+    m_palette = palette;
+    if (m_paletteBasedSettingsForStatus.has_value()) {
+        m_paletteBasedSettingsForStatus = StatusIconSettings::forPalette(m_palette, m_paletteBasedSettingsForStatus.value());
+        m_statusIcons = StatusIcons(m_paletteBasedSettingsForStatus.value());
+    }
+    if (m_paletteBasedSettingsForTray.has_value()) {
+        m_paletteBasedSettingsForTray = StatusIconSettings::forPalette(m_palette, m_paletteBasedSettingsForTray.value());
+        m_trayIcons = StatusIcons(m_paletteBasedSettingsForTray.value());
+    }
+    if (m_paletteBasedSettingsForStatus.has_value() || m_paletteBasedSettingsForTray.has_value()) {
+        emit statusIconsChanged(m_statusIcons, m_trayIcons);
+    }
     emit forkAwesomeIconsChanged(
         m_commonForkAwesomeIcons = ForkAwesomeIcons(m_forkAwesomeRenderer, palette.color(QPalette::Normal, QPalette::Text), QSize(64, 64)));
 }
@@ -348,6 +406,11 @@ IconManager &IconManager::instance(const QPalette *palette)
     return iconManager;
 }
 
+void IconManager::renderForkAwesomeIcon(QtForkAwesome::Icon icon, QPainter *painter, const QRect &rect) const
+{
+    m_forkAwesomeRenderer.render(icon, painter, rect, m_palette.color(QPalette::Normal, QPalette::Text));
+}
+
 QString aboutDialogAttribution()
 {
     return QStringLiteral(
