@@ -7,8 +7,10 @@
 
 #include <QIcon>
 #include <QObject>
+#include <QPalette>
 #include <QSize>
 
+#include <optional>
 #include <vector>
 
 QT_FORWARD_DECLARE_CLASS(QColor)
@@ -99,6 +101,8 @@ struct LIB_SYNCTHING_MODEL_EXPORT StatusIconSettings {
     };
     std::vector<ColorMapping> colorMapping();
     QString toString() const;
+
+    static StatusIconSettings forPalette(const QPalette &palette, const StatusIconSettings &otherSettings);
 };
 
 struct LIB_SYNCTHING_MODEL_EXPORT StatusIcons {
@@ -154,11 +158,13 @@ class LIB_SYNCTHING_MODEL_EXPORT IconManager : public QObject {
 public:
     static IconManager &instance(const QPalette *palette = nullptr);
 
-    void applySettings(const StatusIconSettings *statusIconSettings = nullptr, const StatusIconSettings *trayIconSettings = nullptr);
+    void applySettings(const StatusIconSettings *statusIconSettings = nullptr, const StatusIconSettings *trayIconSettings = nullptr,
+        bool usePaletteForStatus = false, bool usePaletteForTray = false);
     const StatusIcons &statusIcons() const;
     const StatusIcons &trayIcons() const;
     QtForkAwesome::Renderer &forkAwesomeRenderer();
     const ForkAwesomeIcons &commonForkAwesomeIcons() const;
+    void renderForkAwesomeIcon(QtForkAwesome::Icon icon, QPainter *painter, const QRect &rect) const;
 
 public Q_SLOTS:
     void setPalette(const QPalette &palette);
@@ -175,23 +181,12 @@ private:
     StatusIcons m_trayIcons;
     QtForkAwesome::Renderer m_forkAwesomeRenderer;
     ForkAwesomeIcons m_commonForkAwesomeIcons;
+    QPalette m_palette;
+    std::optional<StatusIconSettings> m_paletteBasedSettingsForStatus;
+    std::optional<StatusIconSettings> m_paletteBasedSettingsForTray;
+    bool m_distinguishTrayIcons;
 };
 
-inline void IconManager::applySettings(const StatusIconSettings *statusIconSettings, const StatusIconSettings *trayIconSettings)
-{
-    if (statusIconSettings) {
-        m_statusIcons = StatusIcons(*statusIconSettings);
-    } else {
-        m_statusIcons = StatusIcons(StatusIconSettings());
-    }
-    if (trayIconSettings) {
-        m_trayIcons = StatusIcons(*trayIconSettings);
-    } else {
-        m_trayIcons = m_statusIcons;
-    }
-    emit statusIconsChanged(m_statusIcons, m_trayIcons);
-}
-
 inline const StatusIcons &IconManager::statusIcons() const
 {
     return m_statusIcons;
