@@ -4,42 +4,42 @@
 <context>
     <name>Data::StatusIconSettings</name>
     <message>
-        <location filename="../syncthingicons.cpp" line="231"/>
+        <location filename="../syncthingicons.cpp" line="232"/>
         <source>Misc. notifications</source>
         <translation>Benachrichtigungen</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="232"/>
+        <location filename="../syncthingicons.cpp" line="233"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="233"/>
+        <location filename="../syncthingicons.cpp" line="234"/>
         <source>Warning</source>
         <translation>Warnungen</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="234"/>
+        <location filename="../syncthingicons.cpp" line="235"/>
         <source>Idle</source>
         <translation>Leerlauf</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="235"/>
+        <location filename="../syncthingicons.cpp" line="236"/>
         <source>Scanning</source>
         <translation>Scannen</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="236"/>
+        <location filename="../syncthingicons.cpp" line="237"/>
         <source>Synchronizing</source>
         <translation>Synchronisieren</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="237"/>
+        <location filename="../syncthingicons.cpp" line="238"/>
         <source>Paused</source>
         <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="238"/>
+        <location filename="../syncthingicons.cpp" line="239"/>
         <source>Disconnected</source>
         <translation>Getrennt</translation>
     </message>
@@ -133,49 +133,64 @@
         <translation>nein</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="380"/>
         <source>Paused</source>
-        <translation>Pausiert</translation>
+        <translation type="vanished">Pausiert</translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation type="vanished">Unbekannt</translation>
+    </message>
+    <message>
+        <source>This Device</source>
+        <translation type="vanished">Dieses Gerät</translation>
+    </message>
+    <message>
+        <source>Up to Date</source>
+        <translation type="vanished">Aktuell</translation>
+    </message>
+    <message>
+        <source>Syncing (%1 %, %2)</source>
+        <translation type="vanished">Synchronisiere (%1 %, %2)</translation>
+    </message>
+    <message>
+        <source>Syncing</source>
+        <translation type="vanished">Synchronisiere</translation>
+    </message>
+    <message>
+        <source>Out of Sync</source>
+        <translation type="vanished">Nicht synchronisiert</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="384"/>
         <source>Unknown status</source>
-        <translation>Unbekannter Status</translation>
+        <translation type="vanished">Unbekannter Status</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="386"/>
         <source>This device</source>
-        <translation>Dieses Gerät</translation>
+        <translation type="vanished">Dieses Gerät</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="388"/>
         <source>Idle</source>
-        <translation>Leerlauf</translation>
+        <translation type="vanished">Leerlauf</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="390"/>
         <source>Disconnected</source>
-        <translation>Getrennt</translation>
+        <translation type="vanished">Getrennt</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="395"/>
         <source>Synchronizing</source>
-        <translation>Synchronisiert</translation>
+        <translation type="vanished">Synchronisiert</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="392"/>
         <source>Synchronizing (%1 %, %2)</source>
-        <translation>Synchronisieren (%1 %, %2)</translation>
+        <translation type="vanished">Synchronisieren (%1 %, %2)</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="397"/>
         <source>Out of sync</source>
-        <translation>Nicht synchronisiert</translation>
+        <translation type="vanished">Nicht synchronisiert</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="399"/>
         <source>Rejected</source>
-        <translation>Zurückgewiesen</translation>
+        <translation type="vanished">Zurückgewiesen</translation>
     </message>
 </context>
 <context>
@@ -235,6 +250,34 @@
             <numerusform>&quot;%1&quot; und %2 Elemente nicht synchronisiert</numerusform>
         </translation>
     </message>
+    <message>
+        <source>Waiting to Sync</source>
+        <translation type="vanished">Warten auf die Synchronisation</translation>
+    </message>
+    <message>
+        <source>Preparing to Sync</source>
+        <translation type="vanished">Vorbereiten auf die Synchronisation</translation>
+    </message>
+    <message>
+        <source>Syncing (%1 %)</source>
+        <translation type="vanished">Synchronisiere (%1 %, %2)</translation>
+    </message>
+    <message>
+        <source>Syncing</source>
+        <translation type="vanished">Synchronisiere</translation>
+    </message>
+    <message>
+        <source>Cleaning Versions</source>
+        <translation type="vanished">Versionen bereinigen</translation>
+    </message>
+    <message>
+        <source>Waiting to Clean</source>
+        <translation type="vanished">Warten auf Bereinigung</translation>
+    </message>
+    <message>
+        <source>Out of Sync</source>
+        <translation type="vanished">Nicht synchronisiert</translation>
+    </message>
     <message>
         <location filename="../syncthingdirectorymodel.cpp" line="178"/>
         <source>none</source>
@@ -269,19 +312,16 @@
         <translation>Fehlgeschlagene Elemente</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="466"/>
         <source>Unknown status</source>
-        <translation>Unbekannter Status</translation>
+        <translation type="vanished">Unbekannter Status</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="468"/>
         <source>Idle</source>
-        <translation>Leerlauf</translation>
+        <translation type="vanished">Leerlauf</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="462"/>
         <source>Unshared</source>
-        <translation>Nicht geteilt</translation>
+        <translation type="vanished">Nicht geteilt</translation>
     </message>
     <message>
         <location filename="../syncthingdirectorymodel.cpp" line="128"/>
@@ -304,64 +344,60 @@
         <translation>Typ</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="470"/>
+        <source>Unknown</source>
+        <translation type="vanished">Unbekannt</translation>
+    </message>
+    <message>
+        <source>Up to Date</source>
+        <translation type="vanished">Aktuell</translation>
+    </message>
+    <message>
         <source>Waiting to scan</source>
-        <translation>Warten aufs Scannen</translation>
+        <translation type="vanished">Warten aufs Scannen</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="474"/>
         <source>Scanning (%1 %, %2)</source>
-        <translation>Scannen (%1 %, %2)</translation>
+        <translation type="vanished">Scannen (%1 %, %2)</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="476"/>
         <source>Scanning (%1 %)</source>
-        <translation>Scannen (%1 %)</translation>
+        <translation type="vanished">Scannen (%1 %)</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="478"/>
         <source>Scanning</source>
-        <translation>Scannen</translation>
+        <translation type="vanished">Scannen</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="480"/>
         <source>Waiting to sync</source>
-        <translation>Warten aufs Synchronisieren</translation>
+        <translation type="vanished">Warten aufs Synchronisieren</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="482"/>
         <source>Preparing to sync</source>
-        <translation>Vorbereiten aufs Synchronisieren</translation>
+        <translation type="vanished">Vorbereiten aufs Synchronisieren</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="484"/>
         <source>Synchronizing (%1 %)</source>
-        <translation>Synchronisieren (%1 %)</translation>
+        <translation type="vanished">Synchronisieren (%1 %)</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="484"/>
         <source>Synchronizing</source>
-        <translation>Synchronisieren</translation>
+        <translation type="vanished">Synchronisieren</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="459"/>
         <source>Paused</source>
-        <translation>Pausiert</translation>
+        <translation type="vanished">Pausiert</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="486"/>
         <source>Cleaning</source>
-        <translation>Versionen bereinigen</translation>
+        <translation type="vanished">Versionen bereinigen</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="488"/>
         <source>Waiting to clean</source>
-        <translation>Warten auf Bereinigung</translation>
+        <translation type="vanished">Warten auf Bereinigung</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="490"/>
         <source>Out of sync</source>
-        <translation>Nicht synchronisiert</translation>
+        <translation type="vanished">Nicht synchronisiert</translation>
     </message>
 </context>
 <context>
@@ -377,144 +413,208 @@
         <translation>Fortschritt</translation>
     </message>
 </context>
+<context>
+    <name>Data::SyncthingErrorModel</name>
+    <message>
+        <location filename="../syncthingerrormodel.cpp" line="62"/>
+        <source>Message</source>
+        <translation>Nachricht</translation>
+    </message>
+    <message>
+        <location filename="../syncthingerrormodel.cpp" line="64"/>
+        <source>Time</source>
+        <translation>Zeitpunkt</translation>
+    </message>
+</context>
 <context>
     <name>Data::SyncthingFileModel</name>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="241"/>
+        <location filename="../syncthingfilemodel.cpp" line="291"/>
         <source>Name</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="243"/>
+        <location filename="../syncthingfilemodel.cpp" line="293"/>
         <source>Size</source>
         <translation>Größe</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="245"/>
+        <location filename="../syncthingfilemodel.cpp" line="295"/>
         <source>Last modified</source>
         <translation>Zuletzt geändert</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="247"/>
+        <location filename="../syncthingfilemodel.cpp" line="297"/>
         <source>Ignore pattern</source>
-        <translation type="unfinished"></translation>
+        <translation>Ignoriermuster</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="295"/>
+        <location filename="../syncthingfilemodel.cpp" line="345"/>
         <source>%1 elements</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 Elemente</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="381"/>
+        <location filename="../syncthingfilemodel.cpp" line="226"/>
+        <source>Exists locally and globally</source>
+        <translation>Existiert lokal und global</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="228"/>
+        <source>Exists only globally</source>
+        <translation>Existiert nur global</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="230"/>
+        <source>Exists only locally</source>
+        <translation>Existiert nur lokal</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="232"/>
+        <source>Does not exist</source>
+        <translation>Existiert nicht</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="462"/>
         <source>Refresh</source>
         <translation>Aktualisieren</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="383"/>
+        <location filename="../syncthingfilemodel.cpp" line="465"/>
         <source>Deselect recursively</source>
-        <translation type="unfinished"></translation>
+        <translation>Abwählen (rekursiv)</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="383"/>
+        <location filename="../syncthingfilemodel.cpp" line="465"/>
         <source>Select recursively</source>
-        <translation type="unfinished"></translation>
+        <translation>Auswählen (rekursiv)</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="384"/>
+        <location filename="../syncthingfilemodel.cpp" line="467"/>
         <source>Deselect single item</source>
-        <translation type="unfinished"></translation>
+        <translation>Abwählen (einzelnes Element)</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="384"/>
+        <location filename="../syncthingfilemodel.cpp" line="467"/>
         <source>Select single item</source>
-        <translation type="unfinished"></translation>
+        <translation>Auswählen (einzelnes Element)</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="386"/>
+        <location filename="../syncthingfilemodel.cpp" line="469"/>
         <source>Open local version</source>
-        <translation type="unfinished"></translation>
+        <translation>Lokale Version öffnen</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="386"/>
+        <location filename="../syncthingfilemodel.cpp" line="469"/>
         <source>Copy local path</source>
-        <translation type="unfinished"></translation>
+        <translation>Lokalen Pfad kopieren</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="386"/>
+        <location filename="../syncthingfilemodel.cpp" line="469"/>
         <source>Browse locally</source>
-        <translation type="unfinished"></translation>
+        <translation>Im lokalen Dateibrowser öffnen</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="560"/>
+        <location filename="../syncthingfilemodel.cpp" line="746"/>
+        <source>Select items to sync/ignore</source>
+        <translation>Elemente zum Synchronisieren/Ignorieren auswählen</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="752"/>
+        <source>Discard staged changes</source>
+        <translation>Vorgemerkte Änderungen verwerfen</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="762"/>
         <source>Discard selection and staged changes</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../syncthingfilemodel.cpp" line="591"/>
-        <source>Review and apply staged changes</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../syncthingfilemodel.cpp" line="597"/>
-        <source>Do you want to apply the folliwng changes?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../syncthingfilemodel.cpp" line="604"/>
-        <source>Cannot apply ignore patterns while a previous request for ignore patterns is still pending.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../syncthingfilemodel.cpp" line="612"/>
-        <source>Unable to change ignore patterns:
-%1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../syncthingfilemodel.cpp" line="626"/>
-        <source>Ignore patterns have been changed.</source>
-        <translation type="unfinished"></translation>
+        <translation>Vorgemerkte Änderungen und Auswahl verwerfen</translation>
     </message>
     <message>
         <location filename="../syncthingfilemodel.cpp" line="775"/>
-        <source>Cannot query ignore patterns while a previous request for ignore patterns is still pending.</source>
-        <translation type="unfinished"></translation>
+        <source>Ignore selected items (and their children)</source>
+        <translation>Ausgewählte Elemente ignorieren (und untergeordnete Elemente)</translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="572"/>
-        <source>Remove related ignore patterns</source>
-        <translation type="unfinished"></translation>
+        <location filename="../syncthingfilemodel.cpp" line="780"/>
+        <source>Include selected items (and their children)</source>
+        <translation>Ausgewählte Elemente synchronisieren (und untergeordnete Elemente)</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="787"/>
+        <source>Include all items by default</source>
+        <translation>Alle Elemente standardmäßig synchronisieren</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="787"/>
+        <source>Ignore all items by default</source>
+        <translation>Alle Elemente standardmäßig ignorieren</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="817"/>
+        <source>Remove ignore patterns matching against selected items (may affect other items as well)</source>
+        <translation>Lösche Ignoriermuster die mit ausgewählten Elementen übereinstimmen (kann auch andere Elemente betreffen)</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="845"/>
+        <source>Review and apply staged changes</source>
+        <translation>Vorgemerkte Änderungen überprüfen und anwenden</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="852"/>
+        <source>Do you want to apply the following changes?</source>
+        <translation>Sollen die folgenden Änderungen angewandt werden?</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="860"/>
+        <source>Cannot apply ignore patterns while a previous request for ignore patterns is still pending.</source>
+        <translation>Ignoriermuster können nicht gespeichert werden, da noch eine vorherige Abfrage in Gange ist.</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="868"/>
+        <source>Unable to change ignore patterns:
+%1</source>
+        <translation>Kann Ignoriermuster nicht speichern:
+%1</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="882"/>
+        <source>Ignore patterns have been changed.</source>
+        <translation>Ignoriermuster wurden gespeichert.</translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="1057"/>
+        <source>Cannot query ignore patterns while a previous request for ignore patterns is still pending.</source>
+        <translation>Ignoriermuster können nicht abgefragt werden, da noch eine vorherige Abfrage in Gange ist.</translation>
     </message>
 </context>
 <context>
     <name>Data::SyncthingRecentChangesModel</name>
     <message>
-        <location filename="../syncthingrecentchangesmodel.cpp" line="71"/>
+        <location filename="../syncthingrecentchangesmodel.cpp" line="69"/>
         <source>Action</source>
         <translation>Aktion</translation>
     </message>
     <message>
-        <location filename="../syncthingrecentchangesmodel.cpp" line="73"/>
+        <location filename="../syncthingrecentchangesmodel.cpp" line="71"/>
         <source>Device</source>
         <translation>Gerät</translation>
     </message>
     <message>
-        <location filename="../syncthingrecentchangesmodel.cpp" line="75"/>
+        <location filename="../syncthingrecentchangesmodel.cpp" line="73"/>
         <source>Folder</source>
         <translation>Ordner</translation>
     </message>
     <message>
-        <location filename="../syncthingrecentchangesmodel.cpp" line="77"/>
+        <location filename="../syncthingrecentchangesmodel.cpp" line="75"/>
         <source>Path</source>
         <translation>Pfad</translation>
     </message>
     <message>
-        <location filename="../syncthingrecentchangesmodel.cpp" line="119"/>
+        <location filename="../syncthingrecentchangesmodel.cpp" line="117"/>
         <source>Locally</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../syncthingrecentchangesmodel.cpp" line="119"/>
+        <location filename="../syncthingrecentchangesmodel.cpp" line="117"/>
         <source>Remotely</source>
         <translation></translation>
     </message>
