@@ -4,42 +4,42 @@
 <context>
     <name>Data::StatusIconSettings</name>
     <message>
-        <location filename="../syncthingicons.cpp" line="231"/>
+        <location filename="../syncthingicons.cpp" line="232"/>
         <source>Misc. notifications</source>
         <translation>杂项通知</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="232"/>
+        <location filename="../syncthingicons.cpp" line="233"/>
         <source>Error</source>
         <translation>错误</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="233"/>
+        <location filename="../syncthingicons.cpp" line="234"/>
         <source>Warning</source>
         <translation>警告</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="234"/>
+        <location filename="../syncthingicons.cpp" line="235"/>
         <source>Idle</source>
         <translation>空闲</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="235"/>
+        <location filename="../syncthingicons.cpp" line="236"/>
         <source>Scanning</source>
         <translation>扫描中</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="236"/>
+        <location filename="../syncthingicons.cpp" line="237"/>
         <source>Synchronizing</source>
         <translation>同步中</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="237"/>
+        <location filename="../syncthingicons.cpp" line="238"/>
         <source>Paused</source>
         <translation>已暂停</translation>
     </message>
     <message>
-        <location filename="../syncthingicons.cpp" line="238"/>
+        <location filename="../syncthingicons.cpp" line="239"/>
         <source>Disconnected</source>
         <translation>已断连</translation>
     </message>
@@ -133,49 +133,40 @@
         <translation>否</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="380"/>
         <source>Paused</source>
-        <translation>已暂停</translation>
+        <translation type="vanished">已暂停</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="384"/>
         <source>Unknown status</source>
-        <translation>未知状态</translation>
+        <translation type="vanished">未知状态</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="386"/>
         <source>This device</source>
-        <translation>本设备</translation>
+        <translation type="vanished">本设备</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="388"/>
         <source>Idle</source>
-        <translation>空闲</translation>
+        <translation type="vanished">空闲</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="390"/>
         <source>Disconnected</source>
-        <translation>已断连</translation>
+        <translation type="vanished">已断连</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="392"/>
         <source>Synchronizing (%1 %, %2)</source>
-        <translation>同步中 (%1 %, %2)</translation>
+        <translation type="vanished">同步中 (%1 %, %2)</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="395"/>
         <source>Synchronizing</source>
-        <translation>同步中</translation>
+        <translation type="vanished">同步中</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="397"/>
         <source>Out of sync</source>
-        <translation>未同步</translation>
+        <translation type="vanished">未同步</translation>
     </message>
     <message>
-        <location filename="../syncthingdevicemodel.cpp" line="399"/>
         <source>Rejected</source>
-        <translation>被拒绝</translation>
+        <translation type="vanished">被拒绝</translation>
     </message>
 </context>
 <context>
@@ -287,79 +278,64 @@
         <translation>点击以获取详情</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="459"/>
         <source>Paused</source>
-        <translation>已暂停</translation>
+        <translation type="vanished">已暂停</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="462"/>
         <source>Unshared</source>
-        <translation>未分享</translation>
+        <translation type="vanished">未分享</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="466"/>
         <source>Unknown status</source>
-        <translation>未知状态</translation>
+        <translation type="vanished">未知状态</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="468"/>
         <source>Idle</source>
-        <translation>空闲</translation>
+        <translation type="vanished">空闲</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="470"/>
         <source>Waiting to scan</source>
-        <translation>等待扫描</translation>
+        <translation type="vanished">等待扫描</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="474"/>
         <source>Scanning (%1 %, %2)</source>
-        <translation>扫描中 (%1 %, %2)</translation>
+        <translation type="vanished">扫描中 (%1 %, %2)</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="476"/>
         <source>Scanning (%1 %)</source>
-        <translation>扫描中 (%1 %)</translation>
+        <translation type="vanished">扫描中 (%1 %)</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="478"/>
         <source>Scanning</source>
-        <translation>扫描中</translation>
+        <translation type="vanished">扫描中</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="480"/>
         <source>Waiting to sync</source>
-        <translation>等待同步</translation>
+        <translation type="vanished">等待同步</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="482"/>
         <source>Preparing to sync</source>
-        <translation>准备同步</translation>
+        <translation type="vanished">准备同步</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="484"/>
         <source>Synchronizing (%1 %)</source>
-        <translation>同步中 (%1 %)</translation>
+        <translation type="vanished">同步中 (%1 %)</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="484"/>
         <source>Synchronizing</source>
-        <translation>同步中</translation>
+        <translation type="vanished">同步中</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="486"/>
         <source>Cleaning</source>
-        <translation>清理中</translation>
+        <translation type="vanished">清理中</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="488"/>
         <source>Waiting to clean</source>
-        <translation>等待清理</translation>
+        <translation type="vanished">等待清理</translation>
     </message>
     <message>
-        <location filename="../syncthingdirectorymodel.cpp" line="490"/>
         <source>Out of sync</source>
-        <translation>未同步</translation>
+        <translation type="vanished">未同步</translation>
     </message>
 </context>
 <context>
@@ -375,144 +351,207 @@
         <translation>进度</translation>
     </message>
 </context>
+<context>
+    <name>Data::SyncthingErrorModel</name>
+    <message>
+        <location filename="../syncthingerrormodel.cpp" line="62"/>
+        <source>Message</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingerrormodel.cpp" line="64"/>
+        <source>Time</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>Data::SyncthingFileModel</name>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="241"/>
+        <location filename="../syncthingfilemodel.cpp" line="291"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="243"/>
+        <location filename="../syncthingfilemodel.cpp" line="293"/>
         <source>Size</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="245"/>
+        <location filename="../syncthingfilemodel.cpp" line="295"/>
         <source>Last modified</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="247"/>
+        <location filename="../syncthingfilemodel.cpp" line="297"/>
         <source>Ignore pattern</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="295"/>
+        <location filename="../syncthingfilemodel.cpp" line="345"/>
         <source>%1 elements</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="381"/>
+        <location filename="../syncthingfilemodel.cpp" line="226"/>
+        <source>Exists locally and globally</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="228"/>
+        <source>Exists only globally</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="230"/>
+        <source>Exists only locally</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="232"/>
+        <source>Does not exist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="462"/>
         <source>Refresh</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="383"/>
+        <location filename="../syncthingfilemodel.cpp" line="465"/>
         <source>Deselect recursively</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="383"/>
+        <location filename="../syncthingfilemodel.cpp" line="465"/>
         <source>Select recursively</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="384"/>
+        <location filename="../syncthingfilemodel.cpp" line="467"/>
         <source>Deselect single item</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="384"/>
+        <location filename="../syncthingfilemodel.cpp" line="467"/>
         <source>Select single item</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="386"/>
+        <location filename="../syncthingfilemodel.cpp" line="469"/>
         <source>Open local version</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="386"/>
+        <location filename="../syncthingfilemodel.cpp" line="469"/>
         <source>Copy local path</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="386"/>
+        <location filename="../syncthingfilemodel.cpp" line="469"/>
         <source>Browse locally</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="560"/>
+        <location filename="../syncthingfilemodel.cpp" line="746"/>
+        <source>Select items to sync/ignore</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="752"/>
+        <source>Discard staged changes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="762"/>
         <source>Discard selection and staged changes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="591"/>
+        <location filename="../syncthingfilemodel.cpp" line="775"/>
+        <source>Ignore selected items (and their children)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="780"/>
+        <source>Include selected items (and their children)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="787"/>
+        <source>Include all items by default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="787"/>
+        <source>Ignore all items by default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="817"/>
+        <source>Remove ignore patterns matching against selected items (may affect other items as well)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../syncthingfilemodel.cpp" line="845"/>
         <source>Review and apply staged changes</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="597"/>
-        <source>Do you want to apply the folliwng changes?</source>
+        <location filename="../syncthingfilemodel.cpp" line="852"/>
+        <source>Do you want to apply the following changes?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="604"/>
+        <location filename="../syncthingfilemodel.cpp" line="860"/>
         <source>Cannot apply ignore patterns while a previous request for ignore patterns is still pending.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="612"/>
+        <location filename="../syncthingfilemodel.cpp" line="868"/>
         <source>Unable to change ignore patterns:
 %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="626"/>
+        <location filename="../syncthingfilemodel.cpp" line="882"/>
         <source>Ignore patterns have been changed.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../syncthingfilemodel.cpp" line="775"/>
+        <location filename="../syncthingfilemodel.cpp" line="1057"/>
         <source>Cannot query ignore patterns while a previous request for ignore patterns is still pending.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../syncthingfilemodel.cpp" line="572"/>
-        <source>Remove related ignore patterns</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>Data::SyncthingRecentChangesModel</name>
     <message>
-        <location filename="../syncthingrecentchangesmodel.cpp" line="71"/>
+        <location filename="../syncthingrecentchangesmodel.cpp" line="69"/>
         <source>Action</source>
         <translation>操作</translation>
     </message>
     <message>
-        <location filename="../syncthingrecentchangesmodel.cpp" line="73"/>
+        <location filename="../syncthingrecentchangesmodel.cpp" line="71"/>
         <source>Device</source>
         <translation>设备</translation>
     </message>
     <message>
-        <location filename="../syncthingrecentchangesmodel.cpp" line="75"/>
+        <location filename="../syncthingrecentchangesmodel.cpp" line="73"/>
         <source>Folder</source>
         <translation>目录</translation>
     </message>
     <message>
-        <location filename="../syncthingrecentchangesmodel.cpp" line="77"/>
+        <location filename="../syncthingrecentchangesmodel.cpp" line="75"/>
         <source>Path</source>
         <translation>路径</translation>
     </message>
     <message>
-        <location filename="../syncthingrecentchangesmodel.cpp" line="119"/>
+        <location filename="../syncthingrecentchangesmodel.cpp" line="117"/>
         <source>Locally</source>
         <translation>本地</translation>
     </message>
     <message>
-        <location filename="../syncthingrecentchangesmodel.cpp" line="119"/>
+        <location filename="../syncthingrecentchangesmodel.cpp" line="117"/>
         <source>Remotely</source>
         <translation>远程</translation>
     </message>
