@@ -33,6 +33,8 @@ class SYNCTHINGWIDGETS_EXPORT SyncthingLauncher : public QObject {
     Q_PROPERTY(bool emittingOutput READ isEmittingOutput WRITE setEmittingOutput)
     Q_PROPERTY(std::optional<bool> networkConnectionMetered READ isNetworkConnectionMetered WRITE setNetworkConnectionMetered NOTIFY
             networkConnectionMeteredChanged)
+    Q_PROPERTY(QString meteredStatus READ meteredStatus NOTIFY networkConnectionMeteredChanged)
+    Q_PROPERTY(QString runningStatus READ runningStatus NOTIFY runningChanged)
     Q_PROPERTY(bool stoppingOnMeteredConnection READ isStoppingOnMeteredConnection WRITE setStoppingOnMeteredConnection)
     Q_PROPERTY(QUrl guiUrl READ guiUrl NOTIFY guiUrlChanged)
     Q_PROPERTY(SyncthingProcess *process READ process)
@@ -41,15 +43,22 @@ public:
     explicit SyncthingLauncher(QObject *parent = nullptr);
 
     bool isRunning() const;
+#ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
+    void setRunning(bool running, LibSyncthing::RuntimeOptions &&runtimeOptions);
+#endif
+    QString runningStatus() const;
     CppUtilities::DateTime activeSince() const;
     bool isActiveFor(unsigned int atLeastSeconds) const;
+    bool isActiveWithoutSleepFor(unsigned int atLeastSeconds) const;
     bool isManuallyStopped() const;
     bool isEmittingOutput() const;
     void setEmittingOutput(bool emittingOutput);
     std::optional<bool> isNetworkConnectionMetered() const;
+    QString meteredStatus() const;
     void setNetworkConnectionMetered(std::optional<bool> metered);
     bool isStoppingOnMeteredConnection() const;
     void setStoppingOnMeteredConnection(bool stopOnMeteredConnection);
+    bool shouldLaunchAccordingToSettings() const;
     QString errorString() const;
     QUrl guiUrl() const;
     SyncthingProcess *process();
@@ -70,6 +79,7 @@ Q_SIGNALS:
     void confirmKill();
     void runningChanged(bool isRunning);
     void outputAvailable(const QByteArray &data);
+    void exitLogged(const std::string &exitMessage);
     void exited(int exitCode, QProcess::ExitStatus exitStatus);
     void errorOccurred(QProcess::ProcessError error);
     void guiUrlChanged(const QUrl &newUrl);
@@ -99,17 +109,20 @@ private:
     void handleLoggingCallback(LibSyncthing::LogLevel, const char *message, std::size_t messageSize);
 #endif
     void handleOutputAvailable(QByteArray &&data);
-    void handleGuiListeningUrlFound(CppUtilities::BufferSearch &bufferSearch, std::string &&searchResult);
     void terminateDueToMeteredConnection();
 
     SyncthingProcess m_process;
     QUrl m_guiListeningUrl;
     const Settings::Launcher *m_lastLauncherSettings;
+#ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
+    std::optional<LibSyncthing::RuntimeOptions> m_lastRuntimeOptions;
+#endif
     SyncthingConnection *m_relevantConnection;
     QFuture<void> m_startFuture;
     QFuture<void> m_stopFuture;
     QByteArray m_outputBuffer;
     CppUtilities::BufferSearch m_guiListeningUrlSearch;
+    CppUtilities::BufferSearch m_exitSearch;
     CppUtilities::DateTime m_futureStarted;
 #ifdef SYNCTHINGWIDGETS_USE_LIBSYNCTHING
     LibSyncthing::LogLevel m_libsyncthingLogLevel;
@@ -143,8 +156,14 @@ inline CppUtilities::DateTime SyncthingLauncher::activeSince() const
 /// \brief Checks whether Syncthing is already running for the specified number of seconds.
 inline bool SyncthingLauncher::isActiveFor(unsigned int atLeastSeconds) const
 {
-    const auto activeSince(this->activeSince());
-    return !activeSince.isNull() && (CppUtilities::DateTime::gmtNow() - activeSince).totalSeconds() > atLeastSeconds;
+    return SyncthingProcess::isActiveFor(activeSince(), atLeastSeconds);
+}
+
+/// \brief Checks whether Syncthing is already running for the specified number of seconds.
+/// \remarks Considers only the time since the last wakeup if known; otherwise it is identical to isActiveFor().
+inline bool SyncthingLauncher::isActiveWithoutSleepFor(unsigned int atLeastSeconds) const
+{
+    return m_process.isActiveWithoutSleepFor(activeSince(), atLeastSeconds);
 }
 
 /// \brief Returns whether the Syncthing instance has been manually stopped using SyncthingLauncher::terminate()
@@ -174,6 +193,15 @@ inline bool SyncthingLauncher::isStoppingOnMeteredConnection() const
     return m_stopOnMeteredConnection;
 }
 
+/// \brief Returns whether Syncthing is supposed to be launched according to settings.
+/// \remarks
+/// - The only relevant setting so far is isStoppingOnMeteredConnection().
+/// - One can still launch Syncthing via the launch() functions despite shouldLaunchAccordingToSettings() returning true.
+inline bool SyncthingLauncher::shouldLaunchAccordingToSettings() const
+{
+    return !isStoppingOnMeteredConnection() || !isNetworkConnectionMetered().value_or(false);
+}
+
 /// \brief Returns the last error message.
 inline QString SyncthingLauncher::errorString() const
 {
