@@ -31,8 +31,6 @@
 #include <QFile>
 #include <QMessageBox>
 #include <QSettings>
-#include <QSslCertificate>
-#include <QSslError>
 #include <QStringBuilder>
 #include <QVersionNumber>
 
@@ -169,18 +167,6 @@ void Launcher::terminate()
     killer.waitForFinished();
 }
 
-static bool isActiveFor(const SyncthingLauncher &launcher, unsigned int atLeastSeconds)
-{
-    return launcher.isActiveFor(atLeastSeconds);
-}
-
-#ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
-static bool isActiveFor(const SyncthingService &launcher, unsigned int atLeastSeconds)
-{
-    return launcher.isActiveWithoutSleepFor(atLeastSeconds);
-}
-#endif
-
 /*!
  * \brief Configures the reconnect interval and establishes a connection according to the specified settings/status.
  */
@@ -207,14 +193,14 @@ static inline void connectAccordingToSettings(Data::SyncthingConnection &connect
     // connect instantly if service is running
     if (consideredForReconnect) {
         if (reconnectRequired) {
-            if (isActiveFor(monitor, minActiveTimeInSeconds)) {
+            if (monitor.isActiveWithoutSleepFor(minActiveTimeInSeconds)) {
                 connection.reconnect();
             } else if (isRunning) {
                 // give the service (which has just started) a few seconds to initialize
                 connection.reconnectLater(minActiveTimeInSeconds * 1000);
             }
         } else if (isRunning && !connection.isConnected()) {
-            if (isActiveFor(monitor, minActiveTimeInSeconds)) {
+            if (monitor.isActiveWithoutSleepFor(minActiveTimeInSeconds)) {
                 connection.connect();
             } else {
                 // give the service (which has just started) a few seconds to initialize
@@ -240,7 +226,7 @@ Launcher::LauncherStatus Launcher::apply(
         return LauncherStatus{};
     }
     const auto isRelevant = connection.isLocal();
-    const auto isRunning = launcher->isRunning();
+    const auto isRunning = launcher->isRunning() && !launcher->guiUrl().isEmpty();
     const auto consideredForReconnect = considerForReconnect && isRelevant;
     connectAccordingToSettings(
         connection, currentConnectionSettings, *launcher, reconnectRequired, considerForReconnect, isRelevant, isRunning, consideredForReconnect);
@@ -312,6 +298,7 @@ bool restore()
             connectionSettings->requestTimeout = settings.value(QStringLiteral("requestTimeout"), connectionSettings->requestTimeout).toInt();
             connectionSettings->longPollingTimeout
                 = settings.value(QStringLiteral("longPollingTimeout"), connectionSettings->longPollingTimeout).toInt();
+            connectionSettings->diskEventLimit = settings.value(QStringLiteral("diskEventLimit"), connectionSettings->diskEventLimit).toInt();
             connectionSettings->autoConnect = settings.value(QStringLiteral("autoConnect"), connectionSettings->autoConnect).toBool();
             connectionSettings->pauseOnMeteredConnection
                 = settings.value(QStringLiteral("pauseOnMetered"), connectionSettings->pauseOnMeteredConnection).toBool();
@@ -325,12 +312,14 @@ bool restore()
                         += Data::SyncthingStatusComputionFlags::OutOfSync | Data::SyncthingStatusComputionFlags::UnreadNotifications;
                 }
             }
+#ifndef QT_NO_SSL
             connectionSettings->httpsCertPath = settings.value(QStringLiteral("httpsCertPath")).toString();
             if (!connectionSettings->loadHttpsCert()) {
                 QMessageBox::critical(nullptr, QCoreApplication::applicationName(),
                     QCoreApplication::translate("Settings::restore", "Unable to load certificate \"%1\" when restoring settings.")
                         .arg(connectionSettings->httpsCertPath));
             }
+#endif
         }
     } else {
         v.firstLaunch = true;
@@ -372,6 +361,8 @@ bool restore()
         settings.value(QStringLiteral("trayIconsStrokeWidth"), static_cast<int>(v.icons.tray.strokeWidth)).toInt());
     v.icons.distinguishTrayIcons = settings.value(QStringLiteral("distinguishTrayIcons")).toBool();
     v.icons.preferIconsFromTheme = settings.value(QStringLiteral("preferIconsFromTheme")).toBool();
+    v.icons.usePaletteForStatus = settings.value(QStringLiteral("usePaletteForStatusIcons")).toBool();
+    v.icons.usePaletteForTray = settings.value(QStringLiteral("usePaletteForTrayIcons")).toBool();
     settings.beginGroup(QStringLiteral("positioning"));
     auto &positioning = appearance.positioning;
     positioning.useCursorPosition = settings.value(QStringLiteral("useCursorPos"), positioning.useCursorPosition).toBool();
@@ -437,6 +428,7 @@ bool restore()
     // restore developer settings from environment variables
     setVarFromEnv(v.fakeFirstLaunch, PROJECT_VARNAME_UPPER "_FAKE_FIRST_LAUNCH");
     setVarFromEnv(v.enableWipFeatures, PROJECT_VARNAME_UPPER "_ENABLE_WIP_FEATURES");
+    setVarFromEnv(v.connection.insecure, PROJECT_VARNAME_UPPER "_INSECURE");
 
     return v.error.isEmpty();
 }
@@ -467,13 +459,16 @@ bool save()
         settings.setValue(QStringLiteral("devStatsPollInterval"), connectionSettings->devStatsPollInterval);
         settings.setValue(QStringLiteral("errorsPollInterval"), connectionSettings->errorsPollInterval);
         settings.setValue(QStringLiteral("reconnectInterval"), connectionSettings->reconnectInterval);
+        settings.setValue(QStringLiteral("diskEventLimit"), connectionSettings->diskEventLimit);
         settings.setValue(QStringLiteral("requestTimeout"), connectionSettings->requestTimeout);
         settings.setValue(QStringLiteral("longPollingTimeout"), connectionSettings->longPollingTimeout);
         settings.setValue(QStringLiteral("autoConnect"), connectionSettings->autoConnect);
         settings.setValue(QStringLiteral("pauseOnMetered"), connectionSettings->pauseOnMeteredConnection);
         settings.setValue(QStringLiteral("statusComputionFlags"),
             QVariant::fromValue(static_cast<std::underlying_type_t<Data::SyncthingStatusComputionFlags>>(connectionSettings->statusComputionFlags)));
+#ifndef QT_NO_SSL
         settings.setValue(QStringLiteral("httpsCertPath"), connectionSettings->httpsCertPath);
+#endif
     }
     settings.endArray();
 
@@ -505,6 +500,8 @@ bool save()
     settings.setValue(QStringLiteral("trayIconsStrokeWidth"), static_cast<int>(v.icons.tray.strokeWidth));
     settings.setValue(QStringLiteral("distinguishTrayIcons"), v.icons.distinguishTrayIcons);
     settings.setValue(QStringLiteral("preferIconsFromTheme"), v.icons.preferIconsFromTheme);
+    settings.setValue(QStringLiteral("usePaletteForStatusIcons"), v.icons.usePaletteForStatus);
+    settings.setValue(QStringLiteral("usePaletteForTrayIcons"), v.icons.usePaletteForTray);
     settings.beginGroup(QStringLiteral("positioning"));
     settings.setValue(QStringLiteral("useCursorPos"), appearance.positioning.useCursorPosition);
     settings.setValue(QStringLiteral("useAssumedIconPosition"), appearance.positioning.useAssumedIconPosition);
@@ -666,7 +663,7 @@ void Connection::addConfigFromWizard(const Data::SyncthingConfig &config)
         return;
     }
 
-    // backup previous primary config unless fields going to be overridden are empty anyways
+    // backup previous primary config unless fields going to be overridden are empty anyway
     if (!primary.syncthingUrl.isEmpty() || !primary.userName.isEmpty() || !primary.password.isEmpty() || !primary.apiKey.isEmpty()) {
         auto &backup = secondary.emplace_back(primary);
         backup.label = QCoreApplication::translate("Settings::Connection", "Backup of %1 (created by wizard)").arg(backup.label);
@@ -678,7 +675,9 @@ void Connection::addConfigFromWizard(const Data::SyncthingConfig &config)
     primary.password.clear();
     primary.apiKey = apiKey;
     primary.autoConnect = true; // ensure the connection is actually established when applying
+#ifndef QT_NO_SSL
     primary.httpsCertPath = Data::SyncthingConfig::locateHttpsCertificate();
+#endif
 }
 
 } // namespace Settings
