@@ -131,7 +131,7 @@ QWidget *ConnectionOptionPage::setupWidget()
     ui()->pollErrorsLabel->setToolTip(ui()->pollErrorsSpinBox->toolTip());
     ui()->reconnectLabel->setToolTip(ui()->reconnectSpinBox->toolTip());
     if (m_connection) {
-        QObject::connect(m_connection, &SyncthingConnection::statusChanged, bind(&ConnectionOptionPage::updateConnectionStatus, this));
+        QObject::connect(m_connection, &SyncthingConnection::statusChanged, widget, bind(&ConnectionOptionPage::updateConnectionStatus, this));
     } else {
         hideConnectionStatus();
     }
@@ -234,9 +234,12 @@ bool ConnectionOptionPage::showConnectionSettings(int index)
     ui()->userNameLineEdit->setText(connectionSettings.userName);
     ui()->passwordLineEdit->setText(connectionSettings.password);
     ui()->apiKeyLineEdit->setText(connectionSettings.apiKey);
+#ifndef QT_NO_SSL
     ui()->certPathSelection->lineEdit()->setText(connectionSettings.httpsCertPath);
+#endif
     ui()->timeoutSpinBox->setValue(connectionSettings.requestTimeout);
     ui()->longPollingSpinBox->setValue(connectionSettings.longPollingTimeout);
+    ui()->diskEventLimitSpinBox->setValue(connectionSettings.diskEventLimit);
     ui()->pollTrafficSpinBox->setValue(connectionSettings.trafficPollInterval);
     ui()->pollDevStatsSpinBox->setValue(connectionSettings.devStatsPollInterval);
     ui()->pollErrorsSpinBox->setValue(connectionSettings.errorsPollInterval);
@@ -261,10 +264,13 @@ bool ConnectionOptionPage::cacheCurrentSettings(bool applying)
     connectionSettings.userName = ui()->userNameLineEdit->text();
     connectionSettings.password = ui()->passwordLineEdit->text();
     connectionSettings.apiKey = ui()->apiKeyLineEdit->text().toUtf8();
+#ifndef QT_NO_SSL
     connectionSettings.expectedSslErrors.clear();
     connectionSettings.httpsCertPath = ui()->certPathSelection->lineEdit()->text();
+#endif
     connectionSettings.requestTimeout = ui()->timeoutSpinBox->value();
     connectionSettings.longPollingTimeout = ui()->longPollingSpinBox->value();
+    connectionSettings.diskEventLimit = ui()->diskEventLimitSpinBox->value();
     connectionSettings.trafficPollInterval = ui()->pollTrafficSpinBox->value();
     connectionSettings.devStatsPollInterval = ui()->pollDevStatsSpinBox->value();
     connectionSettings.errorsPollInterval = ui()->pollErrorsSpinBox->value();
@@ -272,6 +278,7 @@ bool ConnectionOptionPage::cacheCurrentSettings(bool applying)
     connectionSettings.autoConnect = ui()->autoConnectCheckBox->isChecked();
     connectionSettings.pauseOnMeteredConnection = ui()->pauseOnMeteredConnectionCheckBox->isChecked();
     connectionSettings.statusComputionFlags = m_statusComputionModel->statusComputionFlags();
+#ifndef QT_NO_SSL
     if (!connectionSettings.loadHttpsCert()) {
         const QString errorMessage = QCoreApplication::translate("QtGui::ConnectionOptionPage", "Unable to load specified certificate \"%1\".")
                                          .arg(connectionSettings.httpsCertPath);
@@ -282,6 +289,7 @@ bool ConnectionOptionPage::cacheCurrentSettings(bool applying)
         }
         return false;
     }
+#endif
     return true;
 }
 
@@ -391,15 +399,15 @@ void ConnectionOptionPage::toggleAdvancedSettings(bool show)
     }
 #if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
     for (auto *const widget : std::initializer_list<QWidget *>{ ui()->authLabel, ui()->userNameLabel, ui()->passwordLabel, ui()->timeoutLabel,
-             ui()->longPollingLabel, ui()->pollLabel, ui()->pauseOnMeteredConnectionCheckBox }) {
+             ui()->longPollingLabel, ui()->diskEventLimitLabel, ui()->pollLabel, ui()->pauseOnMeteredConnectionCheckBox }) {
         ui()->formLayout->setRowVisible(widget, show);
     }
 #else
-    for (auto *const widget :
-        std::initializer_list<QWidget *>{ ui()->authLabel, ui()->authCheckBox, ui()->userNameLabel, ui()->userNameLineEdit, ui()->passwordLabel,
-            ui()->passwordLineEdit, ui()->timeoutLabel, ui()->timeoutSpinBox, ui()->longPollingLabel, ui()->longPollingSpinBox, ui()->pollLabel,
-            ui()->pollDevStatsLabel, ui()->pollDevStatsSpinBox, ui()->pollErrorsLabel, ui()->pollErrorsSpinBox, ui()->pollTrafficLabel,
-            ui()->pollTrafficSpinBox, ui()->reconnectLabel, ui()->reconnectSpinBox, ui()->pauseOnMeteredConnectionCheckBox }) {
+    for (auto *const widget : std::initializer_list<QWidget *>{ ui()->authLabel, ui()->authCheckBox, ui()->userNameLabel, ui()->userNameLineEdit,
+             ui()->passwordLabel, ui()->passwordLineEdit, ui()->timeoutLabel, ui()->timeoutSpinBox, ui()->longPollingLabel, ui()->longPollingSpinBox,
+             ui()->diskEventLimitLabel, ui()->diskEventLimitSpinBox, ui()->pollLabel, ui()->pollDevStatsLabel, ui()->pollDevStatsSpinBox,
+             ui()->pollErrorsLabel, ui()->pollErrorsSpinBox, ui()->pollTrafficLabel, ui()->pollTrafficSpinBox, ui()->reconnectLabel,
+             ui()->reconnectSpinBox, ui()->pauseOnMeteredConnectionCheckBox }) {
         widget->setVisible(show);
     }
 #endif
@@ -582,7 +590,7 @@ void AppearanceOptionPage::reset()
     ui()->showTrafficCheckBox->setChecked(settings.showTraffic);
     ui()->showTabTextsCheckBox->setChecked(settings.showTabTexts);
     ui()->preferIconsFromThemeCheckBox->setChecked(v.icons.preferIconsFromTheme);
-    int index;
+    auto index = int();
     switch (settings.frameStyle & QFrame::Shape_Mask) {
     case QFrame::NoFrame:
         index = 0;
@@ -656,7 +664,7 @@ QWidget *IconsOptionPage::setupWidget()
     // populate form for status icon colors
     auto *const gridLayout = ui()->gridLayout;
     auto *const statusIconsGroupBox = ui()->statusIconsGroupBox;
-    int index = 0;
+    auto index = int();
     for (auto &colorMapping : m_settings.colorMapping()) {
         // populate widgets array
         auto &widgetsForColor = m_widgets[index++] = {
@@ -708,18 +716,25 @@ QWidget *IconsOptionPage::setupWidget()
     auto *const presetsMenu = new QMenu(widget);
     presetsMenu->addAction(QCoreApplication::translate("QtGui::IconsOptionPageBase", "Colorful background with gradient (default)"), widget, [this] {
         m_settings = Data::StatusIconSettings();
+        m_usePalette = false;
         update(true);
     });
     presetsMenu->addAction(
         QCoreApplication::translate("QtGui::IconsOptionPageBase", "Transparent background and dark foreground (for bright themes)"), widget, [this] {
             m_settings = Data::StatusIconSettings(Data::StatusIconSettings::BrightTheme{});
+            m_usePalette = false;
             update(true);
         });
     presetsMenu->addAction(
         QCoreApplication::translate("QtGui::IconsOptionPageBase", "Transparent background and bright foreground (for dark themes)"), widget, [this] {
             m_settings = Data::StatusIconSettings(Data::StatusIconSettings::DarkTheme{});
+            m_usePalette = false;
             update(true);
         });
+    m_paletteAction = presetsMenu->addAction(QString(), widget, [this] {
+        m_usePalette = !m_usePalette;
+        update(true);
+    });
 
     // setup additional buttons
     ui()->restoreDefaultsPushButton->setMenu(presetsMenu);
@@ -754,9 +769,11 @@ bool IconsOptionPage::apply()
     case Context::Combined:
     case Context::UI:
         iconSettings.status = m_settings;
+        iconSettings.usePaletteForStatus = m_usePalette;
         break;
     case Context::System:
         iconSettings.tray = m_settings;
+        iconSettings.usePaletteForTray = m_usePalette;
         iconSettings.distinguishTrayIcons = !ui()->contextCheckBox->isChecked();
         break;
     }
@@ -771,6 +788,10 @@ void IconsOptionPage::update(bool preserveSize)
     } else {
         ui()->renderingSizeSlider->setValue(std::max(m_settings.renderSize.width(), m_settings.renderSize.height()));
     }
+    m_paletteAction->setText(m_usePalette
+            ? QCoreApplication::translate("QtGui::IconsOptionPageBase", "Select colors manually (no longer follow system palette)")
+            : QCoreApplication::translate("QtGui::IconsOptionPageBase", "Transparent background and foreground depending on system palette"));
+    ui()->gridWidget->setDisabled(m_usePalette);
     ui()->thickStrokeWidthCheckBox->setChecked(m_settings.strokeWidth == StatusIconStrokeWidth::Thick);
     for (auto &widgetsForColor : m_widgets) {
         widgetsForColor.colorButtons[0]->setColor(widgetsForColor.setting->backgroundStart);
@@ -786,9 +807,11 @@ void IconsOptionPage::reset()
     case Context::Combined:
     case Context::UI:
         m_settings = iconSettings.status;
+        m_usePalette = iconSettings.usePaletteForStatus;
         break;
     case Context::System:
         m_settings = iconSettings.tray;
+        m_usePalette = iconSettings.usePaletteForTray;
         ui()->contextCheckBox->setChecked(!iconSettings.distinguishTrayIcons);
         break;
     }
@@ -980,6 +1003,8 @@ bool setAutostartPath(const QString &path)
     } else {
         return !launchdPlistFile.exists() || launchdPlistFile.remove();
     }
+#else
+    return false;
 #endif
 }
 
@@ -1442,8 +1467,22 @@ QWidget *SystemdOptionPage::setupWidget()
     QObject::connect(ui()->stopPushButton, &QPushButton::clicked, m_service, &SyncthingService::stop);
     QObject::connect(ui()->enablePushButton, &QPushButton::clicked, m_service, &SyncthingService::enable);
     QObject::connect(ui()->disablePushButton, &QPushButton::clicked, m_service, &SyncthingService::disable);
-    QObject::connect(ui()->stopOnMeteredCheckBox, &QCheckBox::stateChanged, m_service,
-        [s = m_service](int checkState) { s->setStoppingOnMeteredConnection(checkState == Qt::Checked); });
+    QObject::connect(ui()->stopOnMeteredCheckBox,
+        &QCheckBox::
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 7, 0))
+            checkStateChanged
+#else
+            stateChanged
+#endif
+        ,
+        m_service,
+        [s = m_service](
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 7, 0))
+            Qt::CheckState
+#else
+            int
+#endif
+                checkState) { s->setStoppingOnMeteredConnection(checkState == Qt::Checked); });
     m_unitChangedConn
         = QObject::connect(ui()->systemUnitCheckBox, &QCheckBox::clicked, m_service, bind(&SystemdOptionPage::handleSystemUnitChanged, this));
     m_descChangedConn
