@@ -8,7 +8,7 @@ namespace QtGui {
 class DirButtonsItemDelegate : public QStyledItemDelegate {
     Q_OBJECT
 public:
-    DirButtonsItemDelegate(QObject *parent);
+    explicit DirButtonsItemDelegate(QObject *parent);
 
     void paint(QPainter *, const QStyleOptionViewItem &, const QModelIndex &) const override;
 };
