@@ -70,6 +70,13 @@ TrayIcon::TrayIcon(const QString &connectionConfig, QObject *parent)
         tr("Show internal errors"));
     m_errorsAction->setVisible(false);
     connect(m_errorsAction, &QAction::triggered, this, &TrayIcon::showInternalErrorsDialog);
+    auto *const notificationsAction = m_contextMenu.addAction(
+        QIcon::fromTheme(QStringLiteral("emblem-warning"), QIcon(QStringLiteral(":/icons/hicolor/scalable/emblems/8/emblem-warning.svg"))),
+        tr("Show notifications/errors"));
+    notificationsAction->setVisible(widget.connection().hasErrors());
+    connect(&widget.connection(), &SyncthingConnection::newErrors, notificationsAction,
+        [notificationsAction](const std::vector<SyncthingError> &errors) { notificationsAction->setVisible(!errors.empty()); });
+    connect(notificationsAction, &QAction::triggered, &widget, &TrayWidget::showNotifications);
     m_contextMenu.addMenu(trayMenu().widget().connectionsMenu());
     connect(m_contextMenu.addAction(
                 QIcon::fromTheme(QStringLiteral("help-about"), QIcon(QStringLiteral(":/icons/hicolor/scalable/apps/help-about.svg"))), tr("About")),
@@ -93,13 +100,15 @@ TrayIcon::TrayIcon(const QString &connectionConfig, QObject *parent)
     connect(&notifier, &SyncthingNotifier::newDevice, this, &TrayIcon::showNewDev);
     connect(&notifier, &SyncthingNotifier::newDir, this, &TrayIcon::showNewDir);
     connect(&connection, &SyncthingConnection::statusChanged, this, &TrayIcon::updateStatusIconAndText);
+    connect(&connection, &SyncthingConnection::autoReconnectIntervalChanged, this, &TrayIcon::updateStatusIconAndText);
+    connect(&connection, &SyncthingConnection::hasOutOfSyncDirsChanged, this, &TrayIcon::updateStatusIconAndText);
     connect(&connection, &SyncthingConnection::newDevices, this, &TrayIcon::updateStatusIconAndText);
     connect(&connection, &SyncthingConnection::devStatusChanged, this, &TrayIcon::updateStatusIconAndText);
     connect(&IconManager::instance(), &IconManager::statusIconsChanged, this, &TrayIcon::updateStatusIconAndText);
 #ifdef QT_UTILITIES_SUPPORT_DBUS_NOTIFICATIONS
     connect(&m_dbusNotifier, &DBusStatusNotifier::connectRequested, &connection,
         static_cast<void (SyncthingConnection::*)(void)>(&SyncthingConnection::connect));
-    connect(&m_dbusNotifier, &DBusStatusNotifier::dismissNotificationsRequested, &widget, &TrayWidget::dismissNotifications);
+    connect(&m_dbusNotifier, &DBusStatusNotifier::dismissNotificationsRequested, &connection, &SyncthingConnection::requestClearingErrors);
     connect(&m_dbusNotifier, &DBusStatusNotifier::showNotificationsRequested, &widget, &TrayWidget::showNotifications);
     connect(&m_dbusNotifier, &DBusStatusNotifier::errorDetailsRequested, this, &TrayIcon::showInternalErrorsDialog);
     connect(&m_dbusNotifier, &DBusStatusNotifier::webUiRequested, &widget, &TrayWidget::showWebUI);
@@ -133,7 +142,7 @@ void TrayIcon::handleActivated(QSystemTrayIcon::ActivationReason reason)
 {
     switch (reason) {
     case QSystemTrayIcon::Context:
-        // can't catch that event on Plasma 5 anyways
+        // can't catch that event on Plasma anyway
         break;
     case QSystemTrayIcon::MiddleClick:
         trayMenu().widget().showWebUI();
@@ -151,7 +160,7 @@ void TrayIcon::handleMessageClicked()
     case TrayIconMessageClickedAction::None:
         return;
     case TrayIconMessageClickedAction::DismissNotification:
-        trayMenu().widget().dismissNotifications();
+        trayMenu().widget().connection().requestClearingErrors();
         break;
     case TrayIconMessageClickedAction::ShowInternalErrors:
         showInternalErrorsDialog();
