@@ -7,6 +7,7 @@
 #include <syncthingwidgets/misc/otherdialogs.h>
 #include <syncthingwidgets/misc/syncthinglauncher.h>
 #include <syncthingwidgets/misc/textviewdialog.h>
+#include <syncthingwidgets/misc/utils.h>
 #include <syncthingwidgets/settings/settingsdialog.h>
 #include <syncthingwidgets/settings/wizard.h>
 #include <syncthingwidgets/webview/webviewdialog.h>
@@ -74,6 +75,7 @@ TrayWidget::TrayWidget(TrayMenu *parent)
     , m_menu(parent)
     , m_ui(new Ui::TrayWidget)
     , m_webViewDlg(nullptr)
+    , m_notificationsDlg(nullptr)
     , m_internalErrorsButton(nullptr)
     , m_notifier(m_connection)
     , m_dirModel(m_connection)
@@ -107,6 +109,10 @@ TrayWidget::TrayWidget(TrayMenu *parent)
         m_tabTexts << m_ui->tabWidget->tabText(i);
     }
 
+    // configure connection
+    m_connection.setPollingFlags(SyncthingConnection::PollingFlags::MainEvents | SyncthingConnection::PollingFlags::Errors);
+    m_connection.setInsecure(Settings::values().connection.insecure);
+
     // setup models and views
     m_ui->dirsTreeView->header()->setSortIndicator(0, Qt::AscendingOrder);
     m_ui->dirsTreeView->setModel(&m_sortFilterDirModel);
@@ -198,7 +204,7 @@ TrayWidget::TrayWidget(TrayMenu *parent)
     connect(&m_connection, &SyncthingConnection::statusChanged, this, &TrayWidget::handleStatusChanged);
     connect(&m_connection, &SyncthingConnection::trafficChanged, this, &TrayWidget::updateTraffic);
     connect(&m_connection, &SyncthingConnection::dirStatisticsChanged, this, &TrayWidget::updateOverallStatistics);
-    connect(&m_connection, &SyncthingConnection::newNotification, this, &TrayWidget::handleNewNotification);
+    connect(&m_connection, &SyncthingConnection::newErrors, this, &TrayWidget::handleNewErrors);
     connect(m_ui->dirsTreeView, &DirView::openDir, this, &TrayWidget::openDir);
     connect(m_ui->dirsTreeView, &DirView::scanDir, this, &TrayWidget::scanDir);
     connect(m_ui->dirsTreeView, &DirView::pauseResumeDir, this, &TrayWidget::pauseResumeDir);
@@ -208,6 +214,7 @@ TrayWidget::TrayWidget(TrayMenu *parent)
     connect(m_ui->downloadsTreeView, &DownloadView::openDir, this, &TrayWidget::openDir);
     connect(m_ui->downloadsTreeView, &DownloadView::openItemDir, this, &TrayWidget::openItemDir);
     connect(m_ui->recentChangesTreeView, &QTreeView::customContextMenuRequested, this, &TrayWidget::showRecentChangesContextMenu);
+    connect(m_ui->tabWidget, &QTabWidget::currentChanged, this, &TrayWidget::handleCurrentTabChanged);
     connect(scanAllButton, &QPushButton::clicked, &m_connection, &SyncthingConnection::rescanAllDirs);
     connect(viewIdButton, &QPushButton::clicked, this, &TrayWidget::showOwnDeviceId);
     connect(showLogButton, &QPushButton::clicked, this, &TrayWidget::showLog);
@@ -215,10 +222,11 @@ TrayWidget::TrayWidget(TrayMenu *parent)
     connect(restartButton, &QPushButton::clicked, this, &TrayWidget::restartSyncthing);
     connect(m_connectionsActionGroup, &QActionGroup::triggered, this, &TrayWidget::handleConnectionSelected);
     connect(m_ui->actionShowNotifications, &QAction::triggered, this, &TrayWidget::showNotifications);
-    connect(m_ui->actionDismissNotifications, &QAction::triggered, this, &TrayWidget::dismissNotifications);
+    connect(m_ui->actionDismissNotifications, &QAction::triggered, &m_connection, &Data::SyncthingConnection::requestClearingErrors);
     connect(m_ui->startStopPushButton, &QPushButton::clicked, this, &TrayWidget::toggleRunning);
     if (const auto *const launcher = SyncthingLauncher::mainInstance()) {
         connect(launcher, &SyncthingLauncher::runningChanged, this, &TrayWidget::handleLauncherStatusChanged);
+        connect(launcher, &SyncthingLauncher::guiUrlChanged, this, &TrayWidget::handleLauncherGuiAddressChanged);
     }
 #ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
     if (const auto *const service = SyncthingService::mainInstance()) {
@@ -380,11 +388,12 @@ void TrayWidget::showLog()
 
 void TrayWidget::showNotifications()
 {
-    auto *const dlg = TextViewDialog::forLogEntries(m_notifications, tr("New notifications"));
-    dlg->setAttribute(Qt::WA_DeleteOnClose, true);
-    showDialog(dlg, centerWidgetAvoidingOverflow(dlg));
-    m_notifications.clear();
-    dismissNotifications();
+    if (!m_notificationsDlg) {
+        m_notificationsDlg = errorNotificationsDialog(m_connection);
+        m_notificationsDlg->setAttribute(Qt::WA_DeleteOnClose, true);
+        connect(m_notificationsDlg, &QDialog::destroyed, this, &TrayWidget::handleNotificationsDialogDeleted);
+    }
+    showDialog(m_notificationsDlg, centerWidgetAvoidingOverflow(m_notificationsDlg));
 }
 
 void TrayWidget::showUsingPositioningSettings()
@@ -425,15 +434,6 @@ void TrayWidget::showInternalErrorsDialog()
     showDialog(errorViewDlg, centerWidgetAvoidingOverflow(errorViewDlg));
 }
 
-void TrayWidget::dismissNotifications()
-{
-    m_connection.considerAllNotificationsRead();
-    m_ui->notificationsPushButton->setHidden(true);
-    if (m_menu && m_menu->icon()) {
-        m_menu->icon()->updateStatusIconAndText();
-    }
-}
-
 void TrayWidget::restartSyncthing()
 {
     if (QMessageBox::warning(
@@ -586,7 +586,9 @@ void TrayWidget::applySettings(const QString &connectionConfig)
     if (settings.appearance.tabPosition >= QTabWidget::North && settings.appearance.tabPosition <= QTabWidget::East) {
         m_ui->tabWidget->setTabPosition(static_cast<QTabWidget::TabPosition>(settings.appearance.tabPosition));
     }
-    IconManager::instance().applySettings(&settings.icons.status, settings.icons.distinguishTrayIcons ? &settings.icons.tray : nullptr);
+    const auto &iconSettings = settings.icons;
+    IconManager::instance().applySettings(&iconSettings.status, iconSettings.distinguishTrayIcons ? &iconSettings.tray : nullptr,
+        iconSettings.usePaletteForStatus, iconSettings.usePaletteForTray);
     if (m_tabTextsShown != settings.appearance.showTabTexts) {
         const auto tabCount = m_ui->tabWidget->count();
         if ((m_tabTextsShown = settings.appearance.showTabTexts)) {
@@ -618,7 +620,7 @@ void TrayWidget::applySettings(const QString &connectionConfig)
         msgBox->show();
     }
 
-    // conclude wizard immediately if no re-connect was required anyways
+    // conclude wizard immediately if no re-connect was required anyway
     if (!reconnectRequired) {
         concludeWizard();
     }
@@ -653,6 +655,18 @@ bool TrayWidget::event(QEvent *event)
     return res;
 }
 
+void TrayWidget::showEvent(QShowEvent *event)
+{
+    Q_UNUSED(event)
+    QtGui::handleRelevantControlsChanged(true, m_ui->tabWidget->currentIndex(), m_connection);
+}
+
+void TrayWidget::hideEvent(QHideEvent *event)
+{
+    Q_UNUSED(event)
+    QtGui::handleRelevantControlsChanged(false, m_ui->tabWidget->currentIndex(), m_connection);
+}
+
 void TrayWidget::applySettingsOnAllInstances()
 {
     auto &qtSettings = Settings::values().qt;
@@ -723,18 +737,30 @@ void TrayWidget::showIgnorePatterns(const Data::SyncthingDir &dir)
 void TrayWidget::showRecentChangesContextMenu(const QPoint &position)
 {
     const auto *const selectionModel = m_ui->recentChangesTreeView->selectionModel();
-    if (!selectionModel || selectionModel->selectedRows().size() != 1) {
+    const auto indexes = selectionModel ? selectionModel->selectedRows() : QModelIndexList();
+    if (indexes.size() != 1) {
         return;
     }
     const auto copyRole = [this](SyncthingRecentChangesModel::SyncthingRecentChangesModelRole role) {
         return [this, role] {
             const auto *const selectionModelToCopy = m_ui->recentChangesTreeView->selectionModel();
-            if (selectionModelToCopy && selectionModelToCopy->selectedRows().size() == 1) {
-                QGuiApplication::clipboard()->setText(m_recentChangesModel.data(selectionModelToCopy->selectedRows().at(0), role).toString());
+            const auto indexesToCopy = selectionModelToCopy ? selectionModelToCopy->selectedRows() : QModelIndexList();
+            if (indexesToCopy.size() == 1) {
+                QGuiApplication::clipboard()->setText(indexesToCopy.front().data(role).toString());
             }
         };
     };
-    QMenu menu(this);
+    auto menu = QMenu(this);
+    if (auto index = indexes.front(); index.data(SyncthingRecentChangesModel::Action).toString() != QLatin1String("deleted")) {
+        if (auto dirIndex = 0;
+            const auto *const dir = m_connection.findDirInfo(index.data(SyncthingRecentChangesModel::DirectoryId).toString(), dirIndex)) {
+            const auto fullPath = QString(dir->path % QChar('/') % index.data(SyncthingRecentChangesModel::Path).toString());
+            connect(menu.addAction(QIcon::fromTheme(
+                                       QStringLiteral("document-open"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/document-open.svg"))),
+                        tr("Open item")),
+                &QAction::triggered, this, std::bind(&openLocalFileOrDir, fullPath));
+        }
+    }
     connect(menu.addAction(QIcon::fromTheme(QStringLiteral("edit-copy"), QIcon(QStringLiteral(":/icons/hicolor/scalable/actions/edit-copy.svg"))),
                 tr("Copy path")),
         &QAction::triggered, this, copyRole(SyncthingRecentChangesModel::Path));
@@ -748,6 +774,11 @@ void TrayWidget::showRecentChangesContextMenu(const QPoint &position)
     showViewMenu(position, *m_ui->recentChangesTreeView, menu);
 }
 
+void TrayWidget::handleCurrentTabChanged(int index)
+{
+    QtGui::handleRelevantControlsChanged(!isHidden(), index, m_connection);
+}
+
 void TrayWidget::changeStatus()
 {
     switch (m_connection.status()) {
@@ -842,6 +873,16 @@ Settings::Launcher::LauncherStatus TrayWidget::handleLauncherStatusChanged()
     return launcherStatus;
 }
 
+Settings::Launcher::LauncherStatus TrayWidget::handleLauncherGuiAddressChanged(const QUrl &guiAddress)
+{
+    Q_UNUSED(guiAddress)
+#ifdef LIB_SYNCTHING_CONNECTOR_SUPPORT_SYSTEMD
+    return applyLauncherSettings(false, Settings::values().systemd.considerForReconnect, true);
+#else
+    return applyLauncherSettings(false);
+#endif
+}
+
 Settings::Launcher::LauncherStatus TrayWidget::applyLauncherSettings(bool reconnectRequired, bool skipApplyingToConnection, bool skipStartStopButton)
 {
     // update connection
@@ -917,10 +958,9 @@ void TrayWidget::handleWebViewDeleted()
     m_webViewDlg = nullptr;
 }
 
-void TrayWidget::handleNewNotification(DateTime when, const QString &msg)
+void TrayWidget::handleNotificationsDialogDeleted()
 {
-    m_notifications.emplace_back(QString::fromLocal8Bit(when.toString(DateTimeOutputFormat::DateAndTime, true).data()), msg);
-    m_ui->notificationsPushButton->setHidden(false);
+    m_notificationsDlg = nullptr;
 }
 
 void TrayWidget::handleConnectionSelected(QAction *connectionAction)
@@ -942,6 +982,14 @@ void TrayWidget::handleConnectionSelected(QAction *connectionAction)
     }
 }
 
+void TrayWidget::handleNewErrors()
+{
+    m_ui->notificationsPushButton->setVisible(m_connection.hasErrors());
+    if (m_menu && m_menu->icon()) {
+        m_menu->icon()->updateStatusIconAndText();
+    }
+}
+
 void TrayWidget::concludeWizard(const QString &errorMessage)
 {
     if (!m_applyingSettingsForWizard) {
