@@ -1,30 +1,159 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_CN">
+<context>
+    <name>QtGui::App</name>
+    <message>
+        <location filename="../gui/app.cpp" line="115"/>
+        <source>Not connected to backend. Check app settings for problems.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="117"/>
+        <source>Waiting for backend …</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="162"/>
+        <location filename="../gui/app.cpp" line="171"/>
+        <source>Unable to open &quot;%1&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="182"/>
+        <source>Copied value</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="185"/>
+        <source>Unable to copy value</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="194"/>
+        <source>Unable to copy &quot;%1&quot;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="196"/>
+        <source>Copied path</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="206"/>
+        <source>Unable to load ignore patterns: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="227"/>
+        <source>Unable to save ignore patterns: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="351"/>
+        <source>Unable to resolve URL &quot;%1&quot;.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="378"/>
+        <source>Unable to create settings directory under &quot;%1&quot;.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="387"/>
+        <source>Unable to open settings under &quot;%1&quot;: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="402"/>
+        <source>Unable to read settings: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="406"/>
+        <source>Unable to restore settings: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="407"/>
+        <source>JSON document contains no object</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="427"/>
+        <source>Unable to save settings: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="446"/>
+        <source>Unable to load HTTPs certificate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="474"/>
+        <source>This build of the app cannot launch Syncthing.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="482"/>
+        <source>Unable to import settings: settings directory was not located.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="490"/>
+        <source>Unable to import settings: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="493"/>
+        <source>Settings have been imported from &quot;%1&quot;.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="503"/>
+        <source>Unable to create export directory under &quot;%1&quot;.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="507"/>
+        <source>Unable to export settings: settings directory was not located.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="514"/>
+        <source>Unable to export settings: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/app.cpp" line="517"/>
+        <source>Settings have been exported to &quot;%1&quot;.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QtGui::DevView</name>
     <message>
-        <location filename="../gui/devview.cpp" line="60"/>
+        <location filename="../gui/devview.cpp" line="66"/>
         <source>Copy value</source>
         <translation>复制值</translation>
     </message>
     <message>
-        <location filename="../gui/devview.cpp" line="66"/>
+        <location filename="../gui/devview.cpp" line="72"/>
         <source>Copy name</source>
         <translation>复制名字</translation>
     </message>
     <message>
-        <location filename="../gui/devview.cpp" line="69"/>
+        <location filename="../gui/devview.cpp" line="75"/>
         <source>Copy ID</source>
         <translation>复制 ID</translation>
     </message>
     <message>
-        <location filename="../gui/devview.cpp" line="75"/>
+        <location filename="../gui/devview.cpp" line="81"/>
         <source>Resume</source>
         <translation>恢复</translation>
     </message>
     <message>
-        <location filename="../gui/devview.cpp" line="80"/>
+        <location filename="../gui/devview.cpp" line="86"/>
         <source>Pause</source>
         <translation>暂停</translation>
     </message>
@@ -32,37 +161,37 @@
 <context>
     <name>QtGui::DirView</name>
     <message>
-        <location filename="../gui/dirview.cpp" line="77"/>
+        <location filename="../gui/dirview.cpp" line="78"/>
         <source>Copy value</source>
         <translation>复制值</translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="83"/>
+        <location filename="../gui/dirview.cpp" line="84"/>
         <source>Copy label/ID</source>
         <translation>复制 标签/ID</translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="86"/>
+        <location filename="../gui/dirview.cpp" line="87"/>
         <source>Copy path</source>
         <translation>复制路径</translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="91"/>
+        <location filename="../gui/dirview.cpp" line="92"/>
         <source>Rescan</source>
         <translation>重新扫描</translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="96"/>
+        <location filename="../gui/dirview.cpp" line="97"/>
         <source>Resume</source>
         <translation>恢复</translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="101"/>
+        <location filename="../gui/dirview.cpp" line="102"/>
         <source>Pause</source>
         <translation>暂停</translation>
     </message>
     <message>
-        <location filename="../gui/dirview.cpp" line="105"/>
+        <location filename="../gui/dirview.cpp" line="106"/>
         <source>Open in file browser</source>
         <translation>在文件浏览器中打开</translation>
     </message>
@@ -73,24 +202,24 @@
     </message>
     <message>
         <location filename="../gui/dirview.cpp" line="112"/>
-        <source>Show ignore patterns</source>
+        <source>Show/edit ignore patterns</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>QtGui::DownloadView</name>
     <message>
-        <location filename="../gui/downloadview.cpp" line="65"/>
+        <location filename="../gui/downloadview.cpp" line="67"/>
         <source>Copy value</source>
         <translation>复制值</translation>
     </message>
     <message>
-        <location filename="../gui/downloadview.cpp" line="70"/>
+        <location filename="../gui/downloadview.cpp" line="72"/>
         <source>Copy label/ID</source>
         <translation>复制 标签/ID</translation>
     </message>
     <message>
-        <location filename="../gui/downloadview.cpp" line="74"/>
+        <location filename="../gui/downloadview.cpp" line="76"/>
         <source>Open in file browser</source>
         <translation>在文件浏览器中打开</translation>
     </message>
@@ -124,41 +253,46 @@
     </message>
     <message>
         <location filename="../gui/trayicon.cpp" line="75"/>
+        <source>Show notifications/errors</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/trayicon.cpp" line="82"/>
         <source>About</source>
         <translation>关于</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="80"/>
+        <location filename="../gui/trayicon.cpp" line="87"/>
         <source>Close</source>
         <translation>关闭</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="174"/>
+        <location filename="../gui/trayicon.cpp" line="183"/>
         <source>Disconnected from Syncthing</source>
         <translation>从 Syncthing 断开连接</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="213"/>
+        <location filename="../gui/trayicon.cpp" line="222"/>
         <source>Error</source>
         <translation>错误</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="233"/>
+        <location filename="../gui/trayicon.cpp" line="242"/>
         <source>Launcher error</source>
         <translation>启动器错误</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="249"/>
+        <location filename="../gui/trayicon.cpp" line="258"/>
         <source>Syncthing notification - click to dismiss</source>
         <translation>Syncthing 通知 - 点击解除</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="279"/>
+        <location filename="../gui/trayicon.cpp" line="288"/>
         <source>Syncthing device wants to connect - click for web UI</source>
         <translation>Syncthing 设备想要连接 - 点击打开网页 UI</translation>
     </message>
     <message>
-        <location filename="../gui/trayicon.cpp" line="295"/>
+        <location filename="../gui/trayicon.cpp" line="304"/>
         <source>New Syncthing folder - click for web UI</source>
         <translation>新 Syncthing 目录 - 点击打开网页 UI</translation>
     </message>
@@ -178,14 +312,14 @@
     </message>
     <message>
         <location filename="../gui/traywidget.ui" line="72"/>
-        <location filename="../gui/traywidget.cpp" line="863"/>
-        <location filename="../gui/traywidget.cpp" line="905"/>
+        <location filename="../gui/traywidget.cpp" line="904"/>
+        <location filename="../gui/traywidget.cpp" line="946"/>
         <source>Start</source>
         <translation>启动</translation>
     </message>
     <message>
         <location filename="../gui/traywidget.ui" line="99"/>
-        <location filename="../gui/traywidget.cpp" line="343"/>
+        <location filename="../gui/traywidget.cpp" line="351"/>
         <source>About</source>
         <translation>关于</translation>
     </message>
@@ -256,8 +390,7 @@ For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
     </message>
     <message>
         <location filename="../gui/traywidget.ui" line="357"/>
-        <location filename="../gui/traywidget.cpp" line="155"/>
-        <location filename="../gui/traywidget.cpp" line="383"/>
+        <location filename="../gui/traywidget.cpp" line="161"/>
         <source>New notifications</source>
         <translation>新通知</translation>
     </message>
@@ -292,37 +425,37 @@ For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
         <translation>解除</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="127"/>
+        <location filename="../gui/traywidget.cpp" line="133"/>
         <source>View own device ID</source>
         <translation>查看本设备 ID</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="132"/>
+        <location filename="../gui/traywidget.cpp" line="138"/>
         <source>Restart Syncthing</source>
         <translation>重启 Syncthing</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="137"/>
+        <location filename="../gui/traywidget.cpp" line="143"/>
         <source>Show Syncthing log</source>
         <translation>显示 Syncthing 日志</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="142"/>
+        <location filename="../gui/traywidget.cpp" line="148"/>
         <source>Rescan all folders</source>
         <translation>重新扫描全部目录</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="149"/>
+        <location filename="../gui/traywidget.cpp" line="155"/>
         <source>Connection</source>
         <translation>连接</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="171"/>
+        <location filename="../gui/traywidget.cpp" line="177"/>
         <source>Show internal errors</source>
         <translation>显示内部错误</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="186"/>
+        <location filename="../gui/traywidget.cpp" line="192"/>
         <source>Quit Syncthing Tray</source>
         <translation>退出 Syncthing Tray</translation>
     </message>
@@ -372,48 +505,53 @@ For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
         <translation>至少有一个设备已暂停，点击恢复</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="616"/>
+        <location filename="../gui/traywidget.cpp" line="618"/>
         <source>The specified connection configuration &lt;em&gt;%1&lt;/em&gt; is not defined and hence ignored.</source>
         <translation>指定的连接配置 &lt;em&gt;%1&lt;/em&gt; 没有定义，因此被忽略。</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="675"/>
+        <location filename="../gui/traywidget.cpp" line="689"/>
         <source>The folder &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
         <translation>本地设备上不存在目录 &lt;i&gt;%1&lt;/i&gt;。</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="686"/>
+        <location filename="../gui/traywidget.cpp" line="700"/>
         <source>The containing folder &lt;i&gt;%1&lt;/i&gt; does not exist on the local machine.</source>
         <translation>本地设备上不存在包含目录 &lt;i&gt;%1&lt;/i&gt;。</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="739"/>
+        <location filename="../gui/traywidget.cpp" line="760"/>
+        <source>Open item</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../gui/traywidget.cpp" line="765"/>
         <source>Copy path</source>
         <translation>复制路径</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="743"/>
+        <location filename="../gui/traywidget.cpp" line="769"/>
         <source>Copy device ID</source>
         <translation>复制设备 ID</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="746"/>
+        <location filename="../gui/traywidget.cpp" line="772"/>
         <source>Copy folder ID</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="859"/>
-        <location filename="../gui/traywidget.cpp" line="899"/>
+        <location filename="../gui/traywidget.cpp" line="900"/>
+        <location filename="../gui/traywidget.cpp" line="940"/>
         <source>Stop</source>
         <translation>停止</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="860"/>
+        <location filename="../gui/traywidget.cpp" line="901"/>
         <source>Stop Syncthing instance launched via tray icon</source>
         <translation>停止通过托盘图标启动 Syncthing 实例</translation>
     </message>
     <message>
-        <location filename="../gui/traywidget.cpp" line="864"/>
+        <location filename="../gui/traywidget.cpp" line="905"/>
         <source>Start Syncthing with the built-in launcher configured in the settings</source>
         <translation>使用设置中配置的内置启动器启动 Syncthing</translation>
     </message>
@@ -421,12 +559,12 @@ For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
 <context>
     <name>main</name>
     <message>
-        <location filename="../application/main.cpp" line="61"/>
+        <location filename="../application/main.cpp" line="90"/>
         <source>Unable to </source>
         <translation>无法 </translation>
     </message>
     <message>
-        <location filename="../application/main.cpp" line="96"/>
+        <location filename="../application/main.cpp" line="125"/>
         <source>The system tray is (currently) not available. You could open the tray menu as a regular window using the --windowed flag, though.It is also possible to start Syncthing Tray with --wait to wait until the system tray becomes available instead of showing this message.</source>
         <translation>系统托盘当前不可用。不过，您可以使用 --windowed 将托盘菜单作为常规窗口打开。也可以使用 --wait 启动 Syncthing Tray 以等待系统托盘可用，而不是显示此消息。</translation>
     </message>
@@ -439,7 +577,7 @@ For &lt;i&gt;all&lt;/i&gt; notifications, checkout the log</source>
         <translation type="vanished">请注意，设置对话框允许从本地 Syncthing 配置导入 URL、凭据和 API 密钥。</translation>
     </message>
     <message>
-        <location filename="../application/main.cpp" line="123"/>
+        <location filename="../application/main.cpp" line="152"/>
         <source>The Qt libraries have not been built with tray icon support. You could open the tray menu as a regular window using the -w flag, though.</source>
         <translation>Qt 库没有使用托盘图标支持构建。不过，您可以使用 -w 将托盘菜单作为常规窗口打开。</translation>
     </message>
